@@ -17,7 +17,7 @@
 
 #ifndef ABSTRACTDATA_H
 #define ABSTRACTDATA_H
-#include <QObject>
+#include <QThread>
 #include "backupmailutil.h"
 
 class KZip;
@@ -33,6 +33,9 @@ class AbstractData : public QObject
 public:
   explicit AbstractData(QWidget *parent, const QString& filename, BackupMailUtil::BackupTypes typeSelected);
   ~AbstractData();
+
+  virtual void start();
+
 Q_SIGNALS:
   void info(const QString&);
   void error(const QString&);
