@@ -22,14 +22,20 @@
 #include <KSharedConfig>
 class KUrl;
 
+namespace Akonadi {
+  class AgentInstance;
+}
+
 class BackupData : public AbstractData
 {
 public:
-  explicit BackupData(QWidget *parent,BackupMailUtil::BackupTypes typeSelected,const QString& filename);
+  explicit BackupData(QWidget *parent, BackupMailUtil::BackupTypes typeSelected, const QString& filename);
   ~BackupData();
-  void startBackup();
+  void start();
 
 private:
+  void startBackup();
+
   void backupTransports();
   void backupResources();
   void backupMails();
@@ -37,9 +43,11 @@ private:
   void backupIdentity();
   void backupAkonadiDb();
   void backupNepomuk();
+  void writeDirectory(const QString& path, const QString &currentPath, KZip *mailArchive);
   void storeResources(const QString&identifier, const QString& path);
-  KUrl resourcePath(KSharedConfigPtr resourceConfig) const;
+  KUrl resourcePath(const Akonadi::AgentInstance& agent) const;
   void backupFile(const QString&filename, const QString& path, const QString&storedName);
+  bool backupMailData(const KUrl& url, const QString& archivePath);
 
 };
 
