@@ -35,6 +35,8 @@ private Q_SLOTS:
   void slotRestoreData();
   void slotAddInfo(const QString& info);
   void slotAddError(const QString& info);
+  void slotBackupDataFinished();
+  void slotRestoreDataFinished();
 private:
   bool canZip() const;
   void setupActions(bool canZipFile);
