@@ -30,6 +30,8 @@ public:
   explicit SelectionTypeDialog(QWidget * parent);
   ~SelectionTypeDialog();
   BackupMailUtil::BackupTypes backupTypesSelected() const;
+private Q_SLOTS:
+  void slotItemSelected(bool selected);
 
 private:
   SelectTypeWidget *mWidget;
