@@ -33,6 +33,10 @@ public:
   explicit SelectTypeWidget(QWidget *parent = 0);
   ~SelectTypeWidget();
   BackupMailUtil::BackupTypes backupTypesSelected() const;
+private Q_SLOTS:
+  void slotTypeClicked();
+Q_SIGNALS:
+  void itemSelected(bool);
 private:
   Ui::SelectTypeWidget *ui;
 };
