@@ -59,9 +59,7 @@ enum {
 
 static QString cleanSummary( const QString &summary, const KDateTime &next )
 {
-  Q_UNUSED( next ); //remove for KDE4.9
-  //static QString etc = i18nc( "@label an elipsis", "..." );
-  static QString etc = QString( "..." ); //remove and uncomment previous line for KDE4.9
+  static QString etc = i18nc( "@label an elipsis", "..." );
   int maxLen = 40;
 
   QString retStr = summary;
@@ -71,15 +69,14 @@ static QString cleanSummary( const QString &summary, const KDateTime &next )
     retStr = retStr.left( maxLen );
     retStr += etc;
   }
-  /* UNCOMMENT FOR KDE4.9
   if ( next.isValid() ) {
     const QString dateStr =
       KGlobal::locale()->formatDate(
         next.toTimeSpec( CalendarSupport::KCalPrefs::instance()->timeSpec() ).date(),
         KLocale::ShortDate );
-    retStr = i18n( "%1 (next: %2)", retStr, dateStr );
+    retStr = i18nc( "%1 is an item summary. %2 is the date when this item reoccurs",
+                    "%1 (next: %2)", retStr, dateStr );
   }
-  */
   return retStr;
 }
 
@@ -137,8 +134,10 @@ class ListView::Private
     {
     }
 
-    void addIncidences( const Akonadi::Item::List &incidenceList, const QDate & );
-    void addIncidence( const Akonadi::Item &, const QDate &date );
+    void addIncidences( CalendarSupport::Calendar *calendar,
+                        const Akonadi::Item::List &incidenceList, const QDate &date );
+    void addIncidence( CalendarSupport::Calendar *calendar,
+                       const Akonadi::Item &, const QDate &date );
     ListViewItem *getItemForIncidence( const Akonadi::Item & );
 
     QTreeWidget *mTreeWidget;
@@ -364,13 +363,12 @@ void ListView::showDates( const QDate &start, const QDate &end, const QDate &pre
       kEnd.toTimeSpec( CalendarSupport::KCalPrefs::instance()->timeSpec() ).date(),
       KLocale::ShortDate );
 
-//UNCOMMENT FOR KDE4.9
-//  d->mTreeWidget->headerItem()->setText( Summary_Column,
-//                                         i18n( "Summary [%1 - %2]", startStr, endStr ) );
+  d->mTreeWidget->headerItem()->setText( Summary_Column,
+                                         i18n( "Summary [%1 - %2]", startStr, endStr ) );
 
   QDate date = start;
   while ( date <= end ) {
-    d->addIncidences( calendar()->incidences( date ), date );
+    d->addIncidences( calendar(), calendar()->incidences( date ), date );
     d->mSelectedDates.append( date );
     date = date.addDays( 1 );
   }
@@ -383,18 +381,20 @@ void ListView::showDates( const QDate &start, const QDate &end, const QDate &pre
 void ListView::showAll()
 {
   const Akonadi::Item::List incidenceList = calendar()->incidences();
-  d->addIncidences( incidenceList, QDate() );
+  d->addIncidences( calendar(), incidenceList, QDate() );
 }
 
-void ListView::Private::addIncidences( const Akonadi::Item::List &incidenceList,
+void ListView::Private::addIncidences( CalendarSupport::Calendar *calendar,
+                                       const Akonadi::Item::List &incidenceList,
                                        const QDate &date )
 {
   Q_FOREACH ( const Akonadi::Item & i, incidenceList ) {
-    addIncidence( i, date );
+    addIncidence( calendar, i, date );
   }
 }
 
-void ListView::Private::addIncidence( const Akonadi::Item &aitem, const QDate &date )
+void ListView::Private::addIncidence( CalendarSupport::Calendar *calendar,
+                                      const Akonadi::Item &aitem, const QDate &date )
 {
   if ( !CalendarSupport::hasIncidence( aitem ) || mItems.contains( aitem.id() ) ) {
     return;
@@ -422,7 +422,7 @@ void ListView::Private::addIncidence( const Akonadi::Item &aitem, const QDate &d
   for ( int col = 0; col < Dummy_EOF_Column; ++col ) {
     item->setToolTip( col,
                       IncidenceFormatter::toolTipStr(
-                        CalendarSupport::displayName( aitem.parentCollection() ),
+                        CalendarSupport::displayName( calendar, aitem.parentCollection() ),
                         CalendarSupport::incidence( aitem ) ) );
   }
 
@@ -438,7 +438,7 @@ void ListView::showIncidences( const Akonadi::Item::List &incidenceList, const Q
 {
   clear();
 
-  d->addIncidences( incidenceList, date );
+  d->addIncidences( calendar(), incidenceList, date );
 
   updateView();
 
@@ -466,7 +466,7 @@ void ListView::changeIncidenceDisplay( const Akonadi::Item &aitem, int action )
   case CalendarSupport::IncidenceChanger::INCIDENCEADDED:
   {
     if ( date >= f && date <= l ) {
-      d->addIncidence( aitem, date );
+      d->addIncidence( calendar(), aitem, date );
     }
     break;
   }
@@ -479,7 +479,7 @@ void ListView::changeIncidenceDisplay( const Akonadi::Item &aitem, int action )
       d->mDateList.remove( aitem.id() );
     }
     if ( date >= f && date <= l ) {
-      d->addIncidence( aitem, date );
+      d->addIncidence( calendar(), aitem, date );
     }
     break;
   }
