@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,30 +19,27 @@
 #include "ui_importsettingpage.h"
 
 ImportSettingPage::ImportSettingPage(QWidget *parent) :
-    QWidget(parent),
-    ui(new Ui::ImportSettingPage)
+  QWidget(parent),
+  ui(new Ui::ImportSettingPage)
 {
-    ui->setupUi(this);
-    connect( ui->importSettings, SIGNAL(clicked()), SIGNAL(importSettingsClicked()));
+  ui->setupUi(this);
+  connect( ui->importSettings, SIGNAL(clicked()), SIGNAL(importSettingsClicked()));
 }
 
 ImportSettingPage::~ImportSettingPage()
 {
-    delete ui;
+  delete ui;
 }
 
 void ImportSettingPage::addImportInfo( const QString& log )
 {
-    ui->logSettings->addInfoLogEntry( log );
+  ui->logSettings->addInfoLogEntry( log );
 }
 
 void ImportSettingPage::addImportError( const QString& log )
 {
-    ui->logSettings->addErrorLogEntry( log );
+  ui->logSettings->addErrorLogEntry( log );
 }
 
-void ImportSettingPage::setImportButtonEnabled(bool enabled)
-{
-    ui->importSettings->setEnabled(enabled);
-}
 
+#include "importsettingpage.moc"
