@@ -196,6 +196,11 @@ void IncidenceAttendee::save( const KCalCore::Incidence::Ptr &incidence )
     }
   }
 
+  // Must not have an organizer for items without attendees
+  if ( !incidence->attendeeCount() ) {
+    return;
+  }
+
   if ( mUi->mOrganizerStack->currentIndex() == 0 ) {
     incidence->setOrganizer( mUi->mOrganizerCombo->currentText() );
   } else {
