@@ -1,24 +1,46 @@
 /*
-    This file is part of KAddressBook.
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+  This file is part of KAddressBook.
+  Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+  GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  You should have received a copy of the GNU General Public License along
+  with this program; if not, write to the Free Software Foundation, Inc.,
+  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include "vcard_xxport.h"
 
+#include <Akonadi/Contact/ContactViewer>
+
+#ifdef QGPGME_FOUND
+#include <gpgme++/context.h>
+#include <gpgme++/data.h>
+#include <gpgme++/key.h>
+#include <qgpgme/dataprovider.h>
+#endif // QGPGME_FOUND
+
+#include <KABC/VCardConverter>
+
+#include <KApplication>
+#include <KDebug>
+#include <KDialog>
+#include <KFileDialog>
+#include <KLocale>
+#include <KMessageBox>
+#include <KPushButton>
+#include <KTemporaryFile>
+#include <KUrl>
+#include <KIO/NetAccess>
+
 #include <QtCore/QFile>
 #include <QtCore/QPointer>
 #include <QtGui/QCheckBox>
@@ -27,26 +49,7 @@
 #include <QtGui/QLabel>
 #include <QtGui/QPushButton>
 #include <QtGui/QVBoxLayout>
-
-#include <kabc/vcardconverter.h>
-#include <kapplication.h>
-#include <kdebug.h>
-#include <kdialog.h>
-#include <kfiledialog.h>
-#include <kio/netaccess.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kpushbutton.h>
-#include <ktemporaryfile.h>
-#include <kurl.h>
-#include <akonadi/contact/contactviewer.h>
-
-#ifdef QGPGME_FOUND
-#include "gpgme++/context.h"
-#include "gpgme++/data.h"
-#include "gpgme++/key.h"
-#include "qgpgme/dataprovider.h"
-#endif // QGPGME_FOUND
+#include <QtGui/QGroupBox>
 
 class VCardViewerDialog : public KDialog
 {
@@ -82,6 +85,7 @@ class VCardExportSelectionDialog : public KDialog
     bool exportOtherFields() const;
     bool exportEncryptionKeys() const;
     bool exportPictureFields() const;
+    bool exportDisplayName() const;
 
   private:
     QCheckBox *mPrivateBox;
@@ -89,6 +93,7 @@ class VCardExportSelectionDialog : public KDialog
     QCheckBox *mOtherBox;
     QCheckBox *mEncryptionKeys;
     QCheckBox *mPictureBox;
+    QCheckBox *mDisplayNameBox;
 };
 
 VCardXXPort::VCardXXPort( QWidget *parent )
@@ -102,57 +107,76 @@ bool VCardXXPort::exportContacts( const KABC::Addressee::List &contacts ) const
   KUrl url;
 
   const KABC::Addressee::List list = filterContacts( contacts );
-  if ( list.isEmpty() ) // no contact selected
+  if ( list.isEmpty() ) { // no contact selected
     return true;
+  }
 
   bool ok = true;
   if ( list.count() == 1 ) {
-    url = KFileDialog::getSaveUrl( QString(list[ 0 ].givenName() + QLatin1Char('_') + list[ 0 ].familyName() + QLatin1String(".vcf") ) );
-    if ( url.isEmpty() ) // user canceled export
+    url = KFileDialog::getSaveUrl(
+      QString( list[ 0 ].givenName() +
+               QLatin1Char( '_' ) +
+               list[ 0 ].familyName() +
+               QLatin1String( ".vcf" ) ) );
+    if ( url.isEmpty() ) { // user canceled export
       return true;
+    }
 
-    if ( option( "version" ) == "v21" )
+    if ( option( "version" ) == "v21" ) {
       ok = doExport( url, converter.createVCards( list, KABC::VCardConverter::v2_1 ) );
-    else
+    } else {
       ok = doExport( url, converter.createVCards( list, KABC::VCardConverter::v3_0 ) );
+    }
   } else {
-    const QString msg = i18n( "You have selected a list of contacts, shall they be "
-                              "exported to several files?" );
+    const int answer =
+      KMessageBox::questionYesNo(
+        parentWidget(),
+        i18nc( "@info",
+               "You have selected a list of contacts, "
+               "shall they be exported to several files?" ),
+        QString(),
+        KGuiItem( i18nc( "@action:button", "Export to Several Files" ) ),
+        KGuiItem( i18nc( "@action:button", "Export to One File" ) ) );
 
-    switch ( KMessageBox::questionYesNo( parentWidget(), msg, QString(), KGuiItem(i18n( "Export to Several Files" ) ),
-                                         KGuiItem( i18n( "Export to One File" ) ) ) ) {
-      case KMessageBox::Yes: {
-        const KUrl baseUrl = KFileDialog::getExistingDirectoryUrl();
-        if ( baseUrl.isEmpty() )
-          return true; // user canceled export
+    switch( answer ) {
+    case KMessageBox::Yes:
+    {
+      const KUrl baseUrl = KFileDialog::getExistingDirectoryUrl();
+      if ( baseUrl.isEmpty() ) {
+        return true; // user canceled export
+      }
 
-        for ( int i = 0; i < list.count(); ++i ) {
-          const KABC::Addressee contact = list.at( i );
+      for ( int i = 0; i < list.count(); ++i ) {
+        const KABC::Addressee contact = list.at( i );
 
-          url = baseUrl.url() + '/' + contactFileName( contact ) + ".vcf";
+        url = baseUrl.url() + '/' + contactFileName( contact ) + ".vcf";
 
-          bool tmpOk = false;
+        bool tmpOk = false;
 
-          if ( option( "version" ) == "v21" )
-            tmpOk = doExport( url, converter.createVCard( contact, KABC::VCardConverter::v2_1 ) );
-          else
-            tmpOk = doExport( url, converter.createVCard( contact, KABC::VCardConverter::v3_0 ) );
-
-          ok = ok && tmpOk;
+        if ( option( "version" ) == "v21" ) {
+          tmpOk = doExport( url, converter.createVCard( contact, KABC::VCardConverter::v2_1 ) );
+        } else {
+          tmpOk = doExport( url, converter.createVCard( contact, KABC::VCardConverter::v3_0 ) );
         }
-        break;
-      }
-      case KMessageBox::No:
-      default: {
-        url = KFileDialog::getSaveUrl( KUrl( "addressbook.vcf" ) );
-        if ( url.isEmpty() )
-          return true; // user canceled export
 
-        if ( option( "version" ) == "v21" )
-          ok = doExport( url, converter.createVCards( list, KABC::VCardConverter::v2_1 ) );
-        else
-          ok = doExport( url, converter.createVCards( list, KABC::VCardConverter::v3_0 ) );
+        ok = ok && tmpOk;
       }
+      break;
+    }
+    case KMessageBox::No:
+    default:
+    {
+      url = KFileDialog::getSaveUrl( KUrl( "addressbook.vcf" ) );
+      if ( url.isEmpty() ) {
+        return true; // user canceled export
+      }
+
+      if ( option( "version" ) == "v21" ) {
+        ok = doExport( url, converter.createVCards( list, KABC::VCardConverter::v2_1 ) );
+      } else {
+        ok = doExport( url, converter.createVCards( list, KABC::VCardConverter::v3_0 ) );
+      }
+    }
     }
   }
 
@@ -165,19 +189,25 @@ KABC::Addressee::List VCardXXPort::importContacts() const
   KABC::Addressee::List addrList;
   KUrl::List urls;
 
-  if ( !option( "importData" ).isEmpty() )
+  if ( !option( "importData" ).isEmpty() ) {
     addrList = parseVCard( option( "importData" ).toUtf8() );
-  else {
-    if ( !option( "importUrl" ).isEmpty() )
+  } else {
+    if ( !option( "importUrl" ).isEmpty() ) {
       urls.append( KUrl( option( "importUrl" ) ) );
-    else
-      urls = KFileDialog::getOpenUrls( KUrl(), "*.vcf|vCards", parentWidget(),
-                                       i18n( "Select vCard to Import" ) );
+    } else {
+      urls =
+        KFileDialog::getOpenUrls(
+          KUrl(),
+          "*.vcf|vCards",
+          parentWidget(),
+          i18nc( "@title:window", "Select vCard to Import" ) );
+    }
 
-    if ( urls.count() == 0 )
+    if ( urls.count() == 0 ) {
       return addrList;
+    }
 
-    const QString caption( i18n( "vCard Import Failed" ) );
+    const QString caption( i18nc( "@title:window", "vCard Import Failed" ) );
     bool anyFailures = false;
 
     for ( int i = 0; i < urls.count(); ++i ) {
@@ -196,16 +226,21 @@ KABC::Addressee::List VCardXXPort::importContacts() const
 
           KIO::NetAccess::removeTempFile( fileName );
         } else {
-          const QString msg = i18nc( "@info",
-                                     "<para>When trying to read the vCard, there was an error opening the file <filename>%1</filename>:</para>"
-                                     "<para>%2</para>",
-                                     url.pathOrUrl(),
-                                     i18nc( "QFile", file.errorString().toLatin1() ) );
+          const QString msg = i18nc(
+            "@info",
+            "<para>When trying to read the vCard, "
+            "there was an error opening the file <filename>%1</filename>:</para>"
+            "<para>%2</para>",
+            url.pathOrUrl(),
+            i18nc( "QFile", file.errorString().toLatin1() ) );
           KMessageBox::error( parentWidget(), msg, caption );
           anyFailures = true;
         }
       } else {
-        const QString msg = i18nc( "@info", "<para>Unable to access vCard:</para><para>%1</para>", KIO::NetAccess::lastErrorString() );
+        const QString msg = i18nc(
+          "@info",
+          "<para>Unable to access vCard:</para><para>%1</para>",
+          KIO::NetAccess::lastErrorString() );
         KMessageBox::error( parentWidget(), msg, caption );
         anyFailures = true;
       }
@@ -213,14 +248,20 @@ KABC::Addressee::List VCardXXPort::importContacts() const
 
     if ( !option( "importUrl" ).isEmpty() ) { // a vcard was passed via cmd
       if ( addrList.isEmpty() ) {
-        if ( anyFailures && urls.count() > 1 )
-          KMessageBox::information( parentWidget(), i18n( "No contacts were imported, due to errors with the vCards." ) );
-        else if ( !anyFailures )
-          KMessageBox::information( parentWidget(), i18n( "The vCard does not contain any contacts." ) );
+        if ( anyFailures && urls.count() > 1 ) {
+          KMessageBox::information(
+            parentWidget(),
+            i18nc( "@info", "No contacts were imported, due to errors with the vCards." ) );
+        } else if ( !anyFailures ) {
+          KMessageBox::information(
+            parentWidget(),
+            i18nc( "@info", "The vCard does not contain any contacts." ) );
+        }
       } else {
         QPointer<VCardViewerDialog> dlg = new VCardViewerDialog( addrList, parentWidget() );
-        if ( dlg->exec() && dlg )
+        if ( dlg->exec() && dlg ) {
           addrList = dlg->contacts();
+        }
 
         delete dlg;
       }
@@ -240,8 +281,13 @@ KABC::Addressee::List VCardXXPort::parseVCard( const QByteArray &data ) const
 bool VCardXXPort::doExport( const KUrl &url, const QByteArray &data ) const
 {
   if ( url.isLocalFile() && QFileInfo( url.toLocalFile() ).exists() ) {
-    if ( KMessageBox::questionYesNo( parentWidget(), i18n( "Do you want to overwrite file \"%1\"", url.toLocalFile() ) ) == KMessageBox::No )
+    int answer =
+      KMessageBox::questionYesNo(
+        parentWidget(),
+        i18nc( "@info", "Do you want to overwrite file \"%1\"", url.toLocalFile() ) );
+    if ( answer == KMessageBox::No ) {
       return false;
+    }
   }
 
   KTemporaryFile tmpFile;
@@ -257,8 +303,9 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
 {
   KABC::Addressee::List list;
 
-  if ( addrList.isEmpty() )
+  if ( addrList.isEmpty() ) {
     return addrList;
+  }
 
   QPointer<VCardExportSelectionDialog> dlg = new VCardExportSelectionDialog( parentWidget() );
   if ( !dlg->exec() || !dlg ) {
@@ -272,11 +319,29 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
 
     addr.setUid( (*it).uid() );
     addr.setFormattedName( (*it).formattedName() );
-    addr.setPrefix( (*it).prefix() );
-    addr.setGivenName( (*it).givenName() );
-    addr.setAdditionalName( (*it).additionalName() );
-    addr.setFamilyName( (*it).familyName() );
-    addr.setSuffix( (*it).suffix() );
+
+    bool addrDone = false;
+    if ( dlg->exportDisplayName() ) {		// output display name as N field
+      QString fmtName = (*it).formattedName();
+      QStringList splitNames = fmtName.split( ' ', QString::SkipEmptyParts );
+      if ( splitNames.count() >= 2 ) {
+        addr.setPrefix( QString() );
+        addr.setGivenName( splitNames.takeFirst() );
+        addr.setFamilyName( splitNames.takeLast() );
+        addr.setAdditionalName( splitNames.join( " " ) );
+        addr.setSuffix( QString() );
+        addrDone = true;
+      }
+    }
+
+    if ( !addrDone ) {				// not wanted, or could not be split
+      addr.setPrefix( (*it).prefix() );
+      addr.setGivenName( (*it).givenName() );
+      addr.setAdditionalName( (*it).additionalName() );
+      addr.setFamilyName( (*it).familyName() );
+      addr.setSuffix( (*it).suffix() );
+    }
+
     addr.setNickName( (*it).nickName() );
     addr.setMailer( (*it).mailer() );
     addr.setTimeZone( (*it).timeZone() );
@@ -295,11 +360,13 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
     }
 
     if ( dlg->exportPictureFields() ) {
-      if ( dlg->exportPrivateFields() )
+      if ( dlg->exportPrivateFields() ) {
         addr.setPhoto( (*it).photo() );
+      }
 
-      if ( dlg->exportBusinessFields() )
+      if ( dlg->exportBusinessFields() ) {
         addr.setLogo( (*it).logo() );
+      }
     }
 
     if ( dlg->exportBusinessFields() ) {
@@ -310,13 +377,15 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
 
       KABC::PhoneNumber::List phones = (*it).phoneNumbers( KABC::PhoneNumber::Work );
       KABC::PhoneNumber::List::Iterator phoneIt;
-      for ( phoneIt = phones.begin(); phoneIt != phones.end(); ++phoneIt )
+      for ( phoneIt = phones.begin(); phoneIt != phones.end(); ++phoneIt ) {
         addr.insertPhoneNumber( *phoneIt );
+      }
 
       KABC::Address::List addresses = (*it).addresses( KABC::Address::Work );
       KABC::Address::List::Iterator addrIt;
-      for ( addrIt = addresses.begin(); addrIt != addresses.end(); ++addrIt )
+      for ( addrIt = addresses.begin(); addrIt != addresses.end(); ++addrIt ) {
         addr.insertAddress( *addrIt );
+      }
     }
 
     KABC::PhoneNumber::List phones = (*it).phoneNumbers();
@@ -324,12 +393,13 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
     for ( phoneIt = phones.begin(); phoneIt != phones.end(); ++phoneIt ) {
       int type = (*phoneIt).type();
 
-      if ( type & KABC::PhoneNumber::Home && dlg->exportPrivateFields() )
+      if ( type & KABC::PhoneNumber::Home && dlg->exportPrivateFields() ) {
         addr.insertPhoneNumber( *phoneIt );
-      else if ( type & KABC::PhoneNumber::Work && dlg->exportBusinessFields() )
+      } else if ( type & KABC::PhoneNumber::Work && dlg->exportBusinessFields() ) {
         addr.insertPhoneNumber( *phoneIt );
-      else if ( dlg->exportOtherFields() )
+      } else if ( dlg->exportOtherFields() ) {
         addr.insertPhoneNumber( *phoneIt );
+      }
     }
 
     KABC::Address::List addresses = (*it).addresses();
@@ -337,16 +407,18 @@ KABC::Addressee::List VCardXXPort::filterContacts( const KABC::Addressee::List &
     for ( addrIt = addresses.begin(); addrIt != addresses.end(); ++addrIt ) {
       int type = (*addrIt).type();
 
-      if ( type & KABC::Address::Home && dlg->exportPrivateFields() )
+      if ( type & KABC::Address::Home && dlg->exportPrivateFields() ) {
         addr.insertAddress( *addrIt );
-      else if ( type & KABC::Address::Work && dlg->exportBusinessFields() )
+      } else if ( type & KABC::Address::Work && dlg->exportBusinessFields() ) {
         addr.insertAddress( *addrIt );
-      else if ( dlg->exportOtherFields() )
+      } else if ( dlg->exportOtherFields() ) {
         addr.insertAddress( *addrIt );
+      }
     }
 
-    if ( dlg->exportOtherFields() )
+    if ( dlg->exportOtherFields() ) {
       addr.setCustoms( (*it).customs() );
+    }
 
     if ( dlg->exportEncryptionKeys() ) {
       addKey( addr, KABC::Key::PGP );
@@ -365,13 +437,14 @@ void VCardXXPort::addKey( KABC::Addressee &addr, KABC::Key::Type type ) const
 {
 #ifdef QGPGME_FOUND
   const QString fingerprint = addr.custom( "KADDRESSBOOK",
-                                           (type == KABC::Key::PGP ? "OPENPGPFP" : "SMIMEFP") );
-  if ( fingerprint.isEmpty() )
+                                           ( type == KABC::Key::PGP ? "OPENPGPFP" : "SMIMEFP" ) );
+  if ( fingerprint.isEmpty() ) {
     return;
+  }
 
-  GpgME::Context * context = GpgME::Context::createForProtocol( GpgME::OpenPGP );
+  GpgME::Context *context = GpgME::Context::createForProtocol( GpgME::OpenPGP );
   if ( !context ) {
-    kError() <<"No context available";
+    kError() << "No context available";
     return;
   }
 
@@ -404,7 +477,7 @@ VCardViewerDialog::VCardViewerDialog( const KABC::Addressee::List &list, QWidget
   : KDialog( parent ),
     mContacts( list )
 {
-  setCaption( i18n( "Import vCard" ) );
+  setCaption( i18nc( "@title:window", "Import vCard" ) );
   setButtons( Yes | No | Apply | Cancel );
   setDefaultButton( Yes );
   setModal( true );
@@ -417,7 +490,9 @@ VCardViewerDialog::VCardViewerDialog( const KABC::Addressee::List &list, QWidget
   layout->setSpacing( spacingHint() );
   layout->setMargin( marginHint() );
 
-  QLabel *label = new QLabel( i18n( "Do you want to import this contact into your address book?" ), page );
+  QLabel *label =
+    new QLabel(
+      i18nc( "@info", "Do you want to import this contact into your address book?" ), page );
   QFont font = label->font();
   font.setBold( true );
   label->setFont( font );
@@ -426,7 +501,7 @@ VCardViewerDialog::VCardViewerDialog( const KABC::Addressee::List &list, QWidget
   mView = new Akonadi::ContactViewer( page );
   layout->addWidget( mView );
 
-  setButtonText( Apply, i18n( "Import All..." ) );
+  setButtonText( Apply, i18nc( "@action:button", "Import All..." ) );
 
   mIt = mContacts.begin();
 
@@ -448,15 +523,16 @@ void VCardViewerDialog::updateView()
   mView->setRawContact( *mIt );
 
   KABC::Addressee::List::Iterator it = mIt;
-  enableButton( Apply, (++it) != mContacts.end() );
+  enableButton( Apply, ( ++it ) != mContacts.end() );
 }
 
 void VCardViewerDialog::slotYes()
 {
   mIt++;
 
-  if ( mIt == mContacts.end() )
+  if ( mIt == mContacts.end() ) {
     slotApply();
+  }
 
   updateView();
 }
@@ -466,8 +542,9 @@ void VCardViewerDialog::slotNo()
   // remove the current contact from the result set
   mIt = mContacts.erase( mIt );
 
-  if ( mIt == mContacts.end() )
+  if ( mIt == mContacts.end() ) {
     slotApply();
+  }
 
   updateView();
 }
@@ -488,7 +565,7 @@ void VCardViewerDialog::slotCancel()
 VCardExportSelectionDialog::VCardExportSelectionDialog( QWidget *parent )
   : KDialog( parent )
 {
-  setCaption( i18n( "Select vCard Fields" ) );
+  setCaption( i18nc( "@title:window", "Select vCard Fields" ) );
   setButtons( Ok | Cancel );
   setDefaultButton( Ok );
   setModal( true );
@@ -501,24 +578,71 @@ VCardExportSelectionDialog::VCardExportSelectionDialog( QWidget *parent )
   layout->setSpacing( spacingHint() );
   layout->setMargin( marginHint() );
 
-  QLabel *label = new QLabel( i18n( "Select the fields which shall be exported in the vCard." ), page );
-  layout->addWidget( label, 0, 0, 1, 2 );
+  QGroupBox *gbox = new QGroupBox(
+    i18nc( "@title:group", "Fields to be exported" ), page );
+  gbox->setFlat( true );
+  layout->addWidget( gbox, 0, 0, 1, 2 );
 
-  mPrivateBox = new QCheckBox( i18n( "Private fields" ), page );
+  mPrivateBox = new QCheckBox( i18nc( "@option:check", "Private fields" ), page );
+  mPrivateBox->setToolTip(
+    i18nc( "@info:tooltip", "Export private fields" ) );
+  mPrivateBox->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Check this box if you want to export the contact's "
+           "private fields to the vCard output file." ) );
   layout->addWidget( mPrivateBox, 1, 0 );
 
-  mBusinessBox = new QCheckBox( i18n( "Business fields" ), page );
+  mBusinessBox = new QCheckBox( i18nc( "@option:check", "Business fields" ), page );
+  mBusinessBox->setToolTip(
+    i18nc( "@info:tooltip", "Export business fields" ) );
+  mBusinessBox->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Check this box if you want to export the contact's "
+           "business fields to the vCard output file." ) );
   layout->addWidget( mBusinessBox, 2, 0 );
 
-  mOtherBox = new QCheckBox( i18n( "Other fields" ), page );
+  mOtherBox = new QCheckBox( i18nc( "@option:check", "Other fields" ), page );
+  mOtherBox->setToolTip(
+    i18nc( "@info:tooltip", "Export other fields" ) );
+  mOtherBox->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Check this box if you want to export the contact's "
+           "other fields to the vCard output file." ) );
   layout->addWidget( mOtherBox, 3, 0 );
 
-  mEncryptionKeys = new QCheckBox( i18n( "Encryption keys" ), page );
+  mEncryptionKeys = new QCheckBox( i18nc( "@option:check", "Encryption keys" ), page );
+  mEncryptionKeys->setToolTip(
+    i18nc( "@info:tooltip", "Export encryption keys" ) );
+  mEncryptionKeys->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Check this box if you want to export the contact's "
+           "encryption keys to the vCard output file." ) );
   layout->addWidget( mEncryptionKeys, 1, 1 );
 
-  mPictureBox = new QCheckBox( i18n( "Pictures" ), page);
+  mPictureBox = new QCheckBox( i18nc( "@option:check", "Pictures" ), page );
+  mPictureBox->setToolTip(
+    i18nc( "@info:tooltip", "Export pictures" ) );
+  mPictureBox->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Check this box if you want to export the contact's "
+           "picture to the vCard output file." ) );
   layout->addWidget( mPictureBox, 2, 1 );
 
+  gbox = new QGroupBox(
+    i18nc( "@title:group", "Export options" ), page );
+  gbox->setFlat( true );
+  layout->addWidget( gbox, 4, 0, 1, 2 );
+
+  mDisplayNameBox = new QCheckBox( i18nc( "@option:check", "Display name as full name" ), page );
+  mDisplayNameBox->setToolTip(
+    i18nc( "@info:tooltip", "Export display name as full name" ) );
+  mDisplayNameBox->setWhatsThis(
+    i18nc( "@info:whatsthis",
+           "Check this box if you want to export the contact's display name "
+           "in the vCard's full name field.  This may be required to get the "
+           "name shown correctly in GMail or Android." ) );
+  layout->addWidget( mDisplayNameBox, 5, 0, 1, 2 );
+
   KConfig config( "kaddressbookrc" );
   const KConfigGroup group( &config, "XXPortVCard" );
 
@@ -527,6 +651,7 @@ VCardExportSelectionDialog::VCardExportSelectionDialog( QWidget *parent )
   mOtherBox->setChecked( group.readEntry( "ExportOtherFields", true ) );
   mEncryptionKeys->setChecked( group.readEntry( "ExportEncryptionKeys", true ) );
   mPictureBox->setChecked( group.readEntry( "ExportPictureFields", true ) );
+  mDisplayNameBox->setChecked( group.readEntry( "ExportDisplayName", false ) );
 }
 
 VCardExportSelectionDialog::~VCardExportSelectionDialog()
@@ -539,6 +664,7 @@ VCardExportSelectionDialog::~VCardExportSelectionDialog()
   group.writeEntry( "ExportOtherFields", mOtherBox->isChecked() );
   group.writeEntry( "ExportEncryptionKeys", mEncryptionKeys->isChecked() );
   group.writeEntry( "ExportPictureFields", mPictureBox->isChecked() );
+  group.writeEntry( "ExportDisplayName", mDisplayNameBox->isChecked() );
 }
 
 bool VCardExportSelectionDialog::exportPrivateFields() const
@@ -565,3 +691,8 @@ bool VCardExportSelectionDialog::exportPictureFields() const
 {
   return mPictureBox->isChecked();
 }
+
+bool VCardExportSelectionDialog::exportDisplayName() const
+{
+  return mDisplayNameBox->isChecked();
+}
