@@ -207,7 +207,10 @@ KMKernel::KMKernel (QObject *parent, const char *name) :
            this, SLOT(instanceStatusChanged(Akonadi::AgentInstance)) );
 
   connect( Akonadi::AgentManager::self(), SIGNAL(instanceError(Akonadi::AgentInstance,QString)),
-           this, SLOT(instanceError(Akonadi::AgentInstance,QString)) );
+           this, SLOT(slotInstanceError(Akonadi::AgentInstance,QString)) );
+
+  connect( Akonadi::AgentManager::self(), SIGNAL(instanceWarning(Akonadi::AgentInstance,QString)),
+           SLOT(slotInstanceWarning(Akonadi::AgentInstance,QString)) );
 
   connect( Akonadi::AgentManager::self(), SIGNAL(instanceRemoved(Akonadi::AgentInstance)),
            this, SLOT(slotInstanceRemoved(Akonadi::AgentInstance)) );
@@ -614,7 +617,7 @@ int KMKernel::openComposer( const QString &to, const QString &cc,
   }
   else if ( !body.isEmpty() ) {
     context = KMail::Composer::NoTemplate;
-    msg->setBody( body.toUtf8() );
+    msg->setBody( body.toLatin1() );
   }
   else {
     TemplateParser::TemplateParser parser( msg, TemplateParser::TemplateParser::NewMessage );
@@ -784,7 +787,7 @@ QDBusObjectPath KMKernel::openComposer( const QString &to, const QString &cc,
   if ( !subject.isEmpty() ) msg->subject()->fromUnicodeString( subject, "utf-8" );
   if ( !to.isEmpty() )      msg->to()->fromUnicodeString( to, "utf-8" );
   if ( !body.isEmpty() ) {
-    msg->setBody(body.toUtf8());
+    msg->setBody(body.toLatin1());
   } else {
     TemplateParser::TemplateParser parser( msg, TemplateParser::TemplateParser::NewMessage );
     parser.setIdentityManager( KMKernel::self()->identityManager() );
@@ -1910,9 +1913,42 @@ const QAbstractItemModel* KMKernel::treeviewModelSelection()
     return entityTreeModel();
 }
 
-void KMKernel::instanceError(const Akonadi::AgentInstance& instance, const QString & message)
+void KMKernel::slotInstanceWarning(const Akonadi::AgentInstance&instance , const QString& message)
 {
-  kDebug()<<" instance :"<<instance.identifier()<<" received error :"<<message;
+  const QString summary = i18nc( "<source>: <error message>", "%1: %2", instance.name(), message );
+  if( xmlGuiInstance().isValid() ) {
+    KNotification::event( "akonadi-instance-warning",
+                          summary,
+                          QPixmap(),
+                          0,
+                          KNotification::CloseOnTimeout,
+                          xmlGuiInstance() );
+  } else {
+    KNotification::event( "akonadi-instance-warning",
+                          summary,
+                          QPixmap(),
+                          0,
+                          KNotification::CloseOnTimeout );
+  }
+}
+
+void KMKernel::slotInstanceError(const Akonadi::AgentInstance& instance, const QString & message)
+{
+  const QString summary = i18nc( "<source>: <error message>", "%1: %2", instance.name(), message );
+  if( xmlGuiInstance().isValid() ) {
+    KNotification::event( "akonadi-instance-error",
+                          summary,
+                          QPixmap(),
+                          0,
+                          KNotification::CloseOnTimeout,
+                          xmlGuiInstance() );
+  } else {
+    KNotification::event( "akonadi-instance-error",
+                          summary,
+                          QPixmap(),
+                          0,
+                          KNotification::CloseOnTimeout );
+  }
 }
 
 
