@@ -466,7 +466,8 @@ private slots:
 
   void akonadiStateChanged( Akonadi::ServerManager::State );
   void slotProgressItemCompletedOrCanceled( KPIM::ProgressItem * item);
-  void instanceError(const Akonadi::AgentInstance& instance, const QString & message);
+  void slotInstanceError(const Akonadi::AgentInstance& instance, const QString & message);
+  void slotInstanceWarning(const Akonadi::AgentInstance&instance, const QString& message);
   void slotCollectionMoved( const Akonadi::Collection &collection, const Akonadi::Collection &source, const Akonadi::Collection &destination );
   void slotCollectionRemoved(const Akonadi::Collection& col);
   void slotDeleteIdentity( uint identity);
