@@ -48,6 +48,11 @@
 #include <KStandardDirs>
 #include <KRun>
 #include <KMenu>
+#include <KUriFilterData>
+#include <KToolInvocation>
+#include <KUriFilter>
+#include <KStringHandler>
+#include <KPrintPreview>
 
 #include <QVariant>
 #include <qwidget.h>
@@ -65,6 +70,7 @@ MessageActions::MessageActions( KActionCollection *ac, QWidget* parent ) :
     mActionCollection( ac ),
     mMessageView( 0 ),
     mRedirectAction( 0 ),
+    mPrintPreviewAction( 0 ),
     mAsynNepomukRetriever( new MessageCore::AsyncNepomukResourceRetriever( this ) ),
     mCustomTemplatesMenu( 0 )
 {
@@ -155,6 +161,8 @@ MessageActions::MessageActions( KActionCollection *ac, QWidget* parent ) :
            this, SLOT(annotateMessage()) );
 
   mPrintAction = KStandardAction::print( this, SLOT(slotPrintMsg()), mActionCollection );
+  if(KPrintPreview::isAvailable())
+    mPrintPreviewAction = KStandardAction::printPreview( this, SLOT(slotPrintPreviewMsg()), mActionCollection );
 
   mForwardActionMenu  = new KActionMenu(KIcon("mail-forward"), i18nc("Message->","&Forward"), this);
   mActionCollection->addAction("message_forward", mForwardActionMenu );
@@ -199,7 +207,7 @@ MessageActions::MessageActions( KActionCollection *ac, QWidget* parent ) :
 
   connect( mAsynNepomukRetriever, SIGNAL(resourceReceived(QUrl,Nepomuk::Resource)), SLOT(updateAnnotateAction(QUrl,Nepomuk::Resource)) );
 
-  mCustomTemplatesMenu = new CustomTemplatesMenu( parent, ac );
+  mCustomTemplatesMenu = new TemplateParser::CustomTemplatesMenu( parent, ac );
 
   connect( mCustomTemplatesMenu, SIGNAL(replyTemplateSelected(QString)),
            parent, SLOT(slotCustomReplyToMsg(QString)) );
@@ -223,7 +231,7 @@ MessageActions::~MessageActions()
   delete mCustomTemplatesMenu;
 }
 
-CustomTemplatesMenu* MessageActions::customTemplatesMenu() const
+TemplateParser::CustomTemplatesMenu* MessageActions::customTemplatesMenu() const
 {
   return mCustomTemplatesMenu;
 }
@@ -374,8 +382,6 @@ void MessageActions::updateMailingListActions( const Akonadi::Item& messageItem
       }
     }
     mMailingListActionMenu->menu()->clear();
-    qDeleteAll(mMailListActionList);
-    mMailListActionList.clear();
     if ( !listId.isEmpty() )
       mMailingListActionMenu->menu()->addTitle( listId );
 
@@ -518,12 +524,20 @@ void MessageActions::slotMailingListFilter()
   command->start();
 }
 
-
-void MessageActions::slotPrintMsg()
+void MessageActions::printMessage(bool preview)
 {
   if ( mMessageView )
   {
-    mMessageView->viewer()->print();
+    bool result = false;
+    if(GlobalSettings::self()->printSelectedText()) {
+      result = mMessageView->printSelectedText(preview);
+    }
+    if(!result) {
+      if(preview)
+        mMessageView->viewer()->printPreview();
+      else
+        mMessageView->viewer()->print();
+    }
   }
   else
   {
@@ -537,10 +551,21 @@ void MessageActions::slotPrintMsg()
                           0,
                           false, false,
                           useFixedFont, overrideEncoding );
+    command->setPrintPreview(preview);
     command->start();
   }
+
 }
 
+void MessageActions::slotPrintPreviewMsg()
+{
+  printMessage(true);
+}
+
+void MessageActions::slotPrintMsg()
+{
+  printMessage(false);
+}
 
 /**
  * This adds a list of actions to mMailingListActionMenu mapping the identifier item to
@@ -573,7 +598,6 @@ void MessageActions::addMailingListAction( const QString &item, const KUrl &url
   }
   // item is a mailing list url description passed from the updateActions method above.
   KAction *act = new KAction( i18nc( "%1 is a 'Contact Owner' or similar action. %2 is a protocol normally web or email though could be irc/ftp or other url variant", "%1 (%2)",  item, protocol ) , this );
-  mMailListActionList.append(act);
   const QVariant v(  url.url() );
   act-> setData( v );
   act-> setHelpText( prettyUrl );
@@ -624,4 +648,73 @@ void MessageActions::updateAnnotateAction( const QUrl &url, const Nepomuk::Resou
   }
 }
 
+void MessageActions::addWebShortcutsMenu( KMenu *menu, const QString & text )
+{
+    if ( text.isEmpty() )
+        return;
+
+    QString searchText = text;
+    searchText = searchText.replace( QLatin1Char('\n'), QLatin1Char(' ') ).replace( QLatin1Char('\r'), QLatin1Char(' ') ).simplified();
+
+    if ( searchText.isEmpty() )
+        return;
+
+    KUriFilterData filterData( searchText );
+
+    filterData.setSearchFilteringOptions( KUriFilterData::RetrievePreferredSearchProvidersOnly );
+
+    if ( KUriFilter::self()->filterSearchUri( filterData, KUriFilter::NormalTextFilter ) )
+    {
+        const QStringList searchProviders = filterData.preferredSearchProviders();
+
+        if ( !searchProviders.isEmpty() )
+        {
+            KMenu *webShortcutsMenu = new KMenu( menu );
+            webShortcutsMenu->setIcon( KIcon( "preferences-web-browser-shortcuts" ) );
+
+            const QString squeezedText = KStringHandler::rsqueeze( searchText, 21 );
+            webShortcutsMenu->setTitle( i18n( "Search for '%1' with", squeezedText ) );
+
+            KAction *action = 0;
+
+            foreach( const QString &searchProvider, searchProviders )
+            {
+                action = new KAction( searchProvider, webShortcutsMenu );
+                action->setIcon( KIcon( filterData.iconNameForPreferredSearchProvider( searchProvider ) ) );
+                action->setData( filterData.queryForPreferredSearchProvider( searchProvider ) );
+                connect( action, SIGNAL(triggered()), this, SLOT(slotHandleWebShortcutAction()) );
+                webShortcutsMenu->addAction( action );
+            }
+
+            webShortcutsMenu->addSeparator();
+
+            action = new KAction( i18n( "Configure Web Shortcuts..." ), webShortcutsMenu );
+            action->setIcon( KIcon( "configure" ) );
+            connect( action, SIGNAL(triggered()), this, SLOT(slotConfigureWebShortcuts()) );
+            webShortcutsMenu->addAction( action );
+
+            menu->addMenu(webShortcutsMenu);
+        }
+    }
+}
+
+void MessageActions::slotHandleWebShortcutAction()
+{
+  KAction *action = qobject_cast<KAction*>( sender() );
+
+  if (action)
+  {
+      KUriFilterData filterData( action->data().toString() );
+      if ( KUriFilter::self()->filterSearchUri( filterData, KUriFilter::WebShortcutFilter ) )
+      {
+          KToolInvocation::invokeBrowser( filterData.uri().url() );
+      }
+  }
+}
+
+void MessageActions::slotConfigureWebShortcuts()
+{
+ KToolInvocation::kdeinitExec( QLatin1String("kcmshell4"), QStringList() << QLatin1String("ebrowsing") );
+}
+
 #include "messageactions.moc"
