@@ -25,14 +25,14 @@
 */
 
 #include "searchdialog.h"
-#include "koglobals.h"
 #include "calendarview.h"
 
+#include <calendarsupport/kcalprefs.h>
+#include <calendarsupport/utils.h>
+
 #include <calendarviews/eventviews/list/listview.h>
 
-#include <calendarsupport/calendar.h>
-#include <calendarsupport/kcalprefs.h>
-#include <calendarsupport/utils.h>
+#include <KMessageBox>
 
 using namespace KOrg;
 
@@ -112,8 +112,7 @@ void SearchDialog::doSearch()
     KMessageBox::information(
       this,
       i18n( "No items were found that match your search pattern." ),
-      QString(), //TODO: add a caption when string freeze is off
-      QLatin1String( "NoSearchResults" ) );
+      "NoSearchResults" );
   } else {
     mNumItems->setText( i18np( "%1 item","%1 items", mMatchedEvents.count() ) );
   }
@@ -150,7 +149,7 @@ void SearchDialog::search( const QRegExp &re )
       KDateTime::Spec spec = CalendarSupport::KCalPrefs::instance()->timeSpec();
       Akonadi::Item::List alltodos = m_calendarview->calendar()->todos();
       Q_FOREACH ( const Akonadi::Item &item, alltodos ) {
-        const Todo::Ptr todo = CalendarSupport::todo( item );
+        const KCalCore::Todo::Ptr todo = CalendarSupport::todo( item );
         Q_ASSERT( todo );
         if ( ( !todo->hasStartDate() && !todo->hasDueDate() ) || // undated
              ( todo->hasStartDate() &&
@@ -186,7 +185,7 @@ void SearchDialog::search( const QRegExp &re )
   mMatchedEvents.clear();
   Q_FOREACH ( const Akonadi::Item &item,
               CalendarSupport::Calendar::mergeIncidenceList( events, todos, journals ) ) {
-    const Incidence::Ptr ev = CalendarSupport::incidence( item );
+    const KCalCore::Incidence::Ptr ev = CalendarSupport::incidence( item );
     Q_ASSERT( ev );
     if ( mSummaryCheck->isChecked() ) {
       if ( re.indexIn( ev->summary() ) != -1 ) {
