@@ -24,6 +24,7 @@
 #include "mailfilter.h"
 
 #include <Akonadi/Item>
+#include <Akonadi/ServerManager>
 
 #include <QObject>
 
@@ -163,6 +164,9 @@ class MAILCOMMON_EXPORT FilterManager : public QObject
      */
     void endUpdate();
 
+  private Q_SLOTS:
+    void slotServerStateChanged(Akonadi::ServerManager::State);
+
   Q_SIGNALS:
     /**
      * This signal is emitted whenever the filter list has been updated.
