@@ -1,6 +1,6 @@
 /* -*- mode: C++; c-file-style: "gnu" -*-
-  kmsearchpattern.h
-  Author: Marc Mutz <Marc@Mutz.com>
+
+  Author: Marc Mutz <mutz@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,8 +22,7 @@
 
 #include "mailcommon_export.h"
 
-#include <akonadi/kmime/messagestatus.h>
-#include <klocale.h>
+#include <Akonadi/KMime/MessageStatus>
 
 #ifndef KDEPIM_NO_NEPOMUK
 #include <Nepomuk/Query/GroupTerm>
@@ -43,11 +42,11 @@ using Akonadi::MessageStatus;
 class QXmlStreamWriter;
 
 namespace Akonadi {
-class Item;
+  class Item;
 }
 
 namespace KMime {
-class Message;
+  class Message;
 }
 
 class KConfigGroup;
@@ -123,7 +122,7 @@ class MAILCOMMON_EXPORT SearchRule
     /**
      * Initializes this rule with an @p other rule.
      */
-    const SearchRule& operator=( const SearchRule &other );
+    const SearchRule &operator=( const SearchRule &other );
 
     /**
      * Creates a new search rule of a certain type by instantiating the
@@ -201,7 +200,6 @@ class MAILCOMMON_EXPORT SearchRule
      */
     virtual bool requiresBody() const;
 
-
     /**
      * Saves the object into a given config @p group.
      *
@@ -263,22 +261,21 @@ class MAILCOMMON_EXPORT SearchRule
      */
     const QString asString() const;
 
-#ifndef KDEPIM_NO_NEPOMUK 
+#ifndef KDEPIM_NO_NEPOMUK
     /**
      * Adds query terms to the given term group.
      */
     virtual void addQueryTerms( Nepomuk::Query::GroupTerm &groupTerm ) const = 0;
-#endif  
+#endif
 
     /**
      * Adds a serialization of the rule in XESAM format into the stream.
      */
-    virtual void addXesamClause( QXmlStreamWriter& stream ) const = 0;
+    virtual void addXesamClause( QXmlStreamWriter &stream ) const = 0;
 
-    QDataStream& operator>>( QDataStream& ) const;
+    QDataStream &operator>>( QDataStream & ) const;
 
-
-protected:
+  protected:
     /**
      * Helper that returns whether the rule has a negated function.
      */
@@ -293,7 +290,8 @@ protected:
     /**
      * Adds @p term to @p termGroup and adds a negation term inbetween if needed.
      */
-    void addAndNegateTerm( const Nepomuk::Query::Term &term, Nepomuk::Query::GroupTerm &termGroup ) const;
+    void addAndNegateTerm( const Nepomuk::Query::Term &term,
+                           Nepomuk::Query::GroupTerm &termGroup ) const;
 #endif
     /**
      * Converts the rule function into the corresponding Xesam query operator.
@@ -313,7 +311,7 @@ private:
 
 // Needed for MSVC 2010, as it seems to not implicit cast for a pointer anymore
 #ifdef _MSC_VER
-uint qHash(SearchRule::Ptr sr);
+uint qHash( SearchRule::Ptr sr );
 #endif
 
 /**
@@ -345,7 +343,7 @@ class SearchRuleString : public SearchRule
     /**
      * Initializes this rule with an @p other rule.
      */
-    const SearchRuleString& operator=( const SearchRuleString &other );
+    const SearchRuleString &operator=( const SearchRuleString &other );
 
     /**
      * Destroys the string search rule.
@@ -379,23 +377,23 @@ class SearchRuleString : public SearchRule
      */
     virtual void addQueryTerms( Nepomuk::Query::GroupTerm &groupTerm ) const;
 #endif
-    
+
     /**
-     * @copydoc SearchRule::addXesamClause(QXmlStreamWriter& stream )
+     * @copydoc SearchRule::addXesamClause( QXmlStreamWriter &stream )
      */
-    virtual void addXesamClause(QXmlStreamWriter &stream) const;
-private:
+    virtual void addXesamClause( QXmlStreamWriter &stream ) const;
+
+  private:
 #ifndef KDEPIM_NO_NEPOMUK
     /**
      * @copydoc SearchRule::addPersonTerms()
      */
     void addPersonTerm( Nepomuk::Query::GroupTerm &groupTerm, const QUrl &field ) const;
-    void addHeaderTerm (Nepomuk::Query::GroupTerm& groupTerm, const Nepomuk::Query::Term& field) const;
-
+    void addHeaderTerm( Nepomuk::Query::GroupTerm &groupTerm,
+                        const Nepomuk::Query::Term &field ) const;
 #endif
 };
 
-
 /**
  * @short This class represents a search pattern rule operating on numerical values.
  *
@@ -406,7 +404,7 @@ class SearchRuleNumerical : public SearchRule
 {
   public:
     /**
-     * Creates new new numerical search rule.
+     * Creates new numerical search rule.
      *
      * @param field The field to search in.
      * @param function The function to use for searching.
@@ -436,7 +434,7 @@ class SearchRuleNumerical : public SearchRule
      */
     bool matchesInternal( long numericalValue, long numericalContents,
                           const QString &contents ) const;
-                          
+
 #ifndef KDEPIM_NO_NEPOMUK
     /**
      * @copydoc SearchRule::addQueryTerms()
@@ -445,97 +443,154 @@ class SearchRuleNumerical : public SearchRule
 #endif
 
     /**
-     * @copydoc SearchRule::addXesamClause(QXmlStreamWriter& stream )
+     * @copydoc SearchRule::addXesamClause( QXmlStreamWriter &stream )
      */
-    virtual void addXesamClause(QXmlStreamWriter &stream) const;
+    virtual void addXesamClause( QXmlStreamWriter &stream ) const;
 };
 
+
+class SearchRuleDate : public SearchRule
+{
+  public:
+    /**
+     * Creates new date search rule.
+     *
+     * @param field The field to search in.
+     * @param function The function to use for searching.
+     * @param contents The contents to search for.
+     */
+    explicit SearchRuleDate( const QByteArray &field = 0,
+                                  Function function = FuncContains,
+                                  const QString &contents = QString() );
+
+    /**
+     * @copydoc SearchRule::isEmpty()
+     */
+    virtual bool isEmpty() const ;
+
+    /**
+     * @copydoc SearchRule::matches()
+     */
+    virtual bool matches( const Akonadi::Item &item ) const;
+
+    // Optimized matching not implemented, will use the unoptimized matching
+    // from SearchRule
+    using SearchRule::matches;
+
+    /**
+     * A helper method for the main matches() method.
+     * Does the actual comparing.
+     */
+    bool matchesInternal( const QDate& dateValue, const QDate& msgDate ) const;
+
+#ifndef KDEPIM_NO_NEPOMUK
+    /**
+     * @copydoc SearchRule::addQueryTerms()
+     */
+    virtual void addQueryTerms( Nepomuk::Query::GroupTerm &groupTerm ) const;
+#endif
+
+    /**
+     * @copydoc SearchRule::addXesamClause( QXmlStreamWriter &stream )
+     */
+    virtual void addXesamClause( QXmlStreamWriter &stream ) const;
+};
+
+
+
+
+  
 //TODO: Check if the below one is needed or not!
 // The below are used in several places and here so they are accessible.
-  struct MessageStatusInfo {
-    const char *text;
-    const char *icon;
-  };
+struct MessageStatusInfo {
+  const char *text;
+  const char *icon;
+};
 
-  // If you change the ordering here; also do it in the enum below
-  static const MessageStatusInfo StatusValues[] = {
-    { I18N_NOOP2( "message status", "Important" ),              "emblem-important"    },
-    { I18N_NOOP2( "message status", "Action Item" ),            "mail-task"           },
-    { I18N_NOOP2( "message status", "Unread" ),                 "mail-unread"         },
-    { I18N_NOOP2( "message status", "Read" ),                   "mail-read"           },
-    { I18N_NOOP2( "message status", "Deleted" ),                "mail-deleted"        },
-    { I18N_NOOP2( "message status", "Replied" ),                "mail-replied"        },
-    { I18N_NOOP2( "message status", "Forwarded" ),              "mail-forwarded"      },
-    { I18N_NOOP2( "message status", "Queued" ),                 "mail-queued"         },
-    { I18N_NOOP2( "message status", "Sent" ),                   "mail-sent"           },
-    { I18N_NOOP2( "message status", "Watched" ),                "mail-thread-watch"   },
-    { I18N_NOOP2( "message status", "Ignored" ),                "mail-thread-ignored" },
-    { I18N_NOOP2( "message status", "Spam" ),                   "mail-mark-junk"      },
-    { I18N_NOOP2( "message status", "Ham" ),                    "mail-mark-notjunk"   },
-    { I18N_NOOP2( "message status", "Has Attachment"),          "mail-attachment"     } //must be last
-  };
-  // If you change the ordering here; also do it in the array above
-  enum StatusValueTypes {
-    StatusImportant = 0,
-    StatusToAct = 1,
-    StatusUnread = 2,
-    StatusRead = 3,
-    StatusDeleted = 4,
-    StatusReplied = 5,
-    StatusForwarded = 6,
-    StatusQueued = 7,
-    StatusSent = 8,
-    StatusWatched = 9,
-    StatusIgnored = 10,
-    StatusSpam = 11,
-    StatusHam = 12,
-    StatusHasAttachment = 13 //must be last
-  };
+// If you change the ordering here; also do it in the enum below
+static const MessageStatusInfo StatusValues[] =
+{
+  { I18N_NOOP2( "message status", "Important" ),     "emblem-important"    },
+  { I18N_NOOP2( "message status", "Action Item" ),   "mail-task"           },
+  { I18N_NOOP2( "message status", "Unread" ),        "mail-unread"         },
+  { I18N_NOOP2( "message status", "Read" ),          "mail-read"           },
+  { I18N_NOOP2( "message status", "Deleted" ),       "mail-deleted"        },
+  { I18N_NOOP2( "message status", "Replied" ),       "mail-replied"        },
+  { I18N_NOOP2( "message status", "Forwarded" ),     "mail-forwarded"      },
+  { I18N_NOOP2( "message status", "Queued" ),        "mail-queued"         },
+  { I18N_NOOP2( "message status", "Sent" ),          "mail-sent"           },
+  { I18N_NOOP2( "message status", "Watched" ),       "mail-thread-watch"   },
+  { I18N_NOOP2( "message status", "Ignored" ),       "mail-thread-ignored" },
+  { I18N_NOOP2( "message status", "Spam" ),          "mail-mark-junk"      },
+  { I18N_NOOP2( "message status", "Ham" ),           "mail-mark-notjunk"   },
+  { I18N_NOOP2( "message status", "Has Attachment"), "mail-attachment"     } //must be last
+};
 
-  static const int StatusValueCount =
-    sizeof( StatusValues ) / sizeof( MessageStatusInfo );
-  // we want to show all status entries in the quick search bar, but only the
-  // ones up to attachment in the search/filter dialog, because there the
-  // attachment case is handled separately.
-  static const int StatusValueCountWithoutHidden = StatusValueCount - 1;
+// If you change the ordering here; also do it in the array above
+enum StatusValueTypes {
+  StatusImportant = 0,
+  StatusToAct = 1,
+  StatusUnread = 2,
+  StatusRead = 3,
+  StatusDeleted = 4,
+  StatusReplied = 5,
+  StatusForwarded = 6,
+  StatusQueued = 7,
+  StatusSent = 8,
+  StatusWatched = 9,
+  StatusIgnored = 10,
+  StatusSpam = 11,
+  StatusHam = 12,
+  StatusHasAttachment = 13 //must be last
+};
 
+static const int StatusValueCount =
+  sizeof( StatusValues ) / sizeof( MessageStatusInfo );
+// we want to show all status entries in the quick search bar, but only the
+// ones up to attachment in the search/filter dialog, because there the
+// attachment case is handled separately.
+static const int StatusValueCountWithoutHidden = StatusValueCount - 1;
 
-/** This class represents a search to be performed against the status of a
+/**
+ *  This class represents a search to be performed against the status of a
  *  messsage. The status is represented by a bitfield.
-    @short This class represents a search pattern rule operating on message
-    status.
-*/
+ *
+ *  @short This class represents a search pattern rule operating on message
+ *  status.
+ */
 class MAILCOMMON_EXPORT SearchRuleStatus : public SearchRule
 {
-public:
-   explicit SearchRuleStatus( const QByteArray & field=0, Function function=FuncContains,
-                                const QString & contents=QString() );
-   explicit SearchRuleStatus( Akonadi::MessageStatus status, Function function=FuncContains );
+  public:
+    explicit SearchRuleStatus( const QByteArray &field = 0,
+                               Function function = FuncContains,
+                               const QString &contents = QString() );
+
+    explicit SearchRuleStatus( Akonadi::MessageStatus status,
+                               Function function = FuncContains );
+
+    virtual bool isEmpty() const ;
+    virtual bool matches( const Akonadi::Item &item ) const;
 
-   virtual bool isEmpty() const ;
-   virtual bool matches( const Akonadi::Item &item ) const;
-   
 #ifndef KDEPIM_NO_NEPOMUK
-   virtual void addQueryTerms( Nepomuk::Query::GroupTerm &groupTerm ) const;
-#endif   
-
-   //Not possible to implement optimized form for status searching
-   using SearchRule::matches;
-
-
-  static Akonadi::MessageStatus statusFromEnglishName(const QString&);
-  /**
-   * @copydoc SearchRule::addXesamClause(QXmlStreamWriter& stream )
-   */
-  virtual void addXesamClause(QXmlStreamWriter &stream) const;
-
-private:
-#ifndef KDEPIM_NO_NEPOMUK
-  void addTagTerm( Nepomuk::Query::GroupTerm &groupTerm, const QString &tagId ) const;
+    virtual void addQueryTerms( Nepomuk::Query::GroupTerm &groupTerm ) const;
 #endif
-  
-private:
-   Akonadi::MessageStatus mStatus;
+
+    //Not possible to implement optimized form for status searching
+    using SearchRule::matches;
+
+    static Akonadi::MessageStatus statusFromEnglishName( const QString & );
+    /**
+     * @copydoc SearchRule::addXesamClause( QXmlStreamWriter &stream )
+     */
+    virtual void addXesamClause( QXmlStreamWriter &stream ) const;
+
+  private:
+#ifndef KDEPIM_NO_NEPOMUK
+    void addTagTerm( Nepomuk::Query::GroupTerm &groupTerm, const QString &tagId ) const;
+#endif
+
+  private:
+    Akonadi::MessageStatus mStatus;
 };
 
 // ------------------------------------------------------------------------
@@ -556,7 +611,7 @@ private:
     reuse a rule in another pattern, make a deep copy of that rule.
 
     @short An abstraction of a search over messages.
-    @author Marc Mutz <Marc@Mutz.com>
+    @author Marc Mutz <mutz@kde.org>
 */
 class MAILCOMMON_EXPORT SearchPattern : public QList<SearchRule::Ptr>
 {
