@@ -46,12 +46,14 @@ class KActionCollection;
 class KSelectAction;
 class KToggleAction;
 class KHBox;
+class KMenu;
 
 class QPoint;
 class QSplitter;
 class QStyle;
 class QModelIndex;
 class QTreeView;
+class QActionGroup;
 
 namespace KParts {
   struct BrowserArguments;
@@ -73,6 +75,7 @@ namespace MessageViewer {
   class WebKitPartHtmlWriter;
   class HtmlStatusBar;
   class MailWebView;
+  class TranslatorWidget;
 }
 
 namespace MessageViewer {
@@ -156,7 +159,7 @@ TODO: This temp file handling is a big mess and could use a rewrite, especially
       on demand. There shouldn't be the need to write out tempfiles until really needed.
 
 Some header styles display an attachment list in the header. The HTML code for the attachment list
-can not be generated by the HeaderStyle itself, since that does not know about all attachments.
+cannot be generated by the HeaderStyle itself, since that does not know about all attachments.
 Therefore, the attachment list needs to be created by ViewerPrivate. For this, the HeaderStyle
 writes out a placeholder for the attachment list when it creates the HTML for the header. Once the
 ObjectTreeParser is finished with the message, injectAttachments() is called. injectAttachments()
@@ -278,7 +281,8 @@ private:
   void initHtmlWidget();
   void saveMimePartTreeConfig();
   void restoreMimePartTreeConfig();
-
+  void createOpenWithMenu( KMenu *topMenu, KMime::Content* node );
+  KAction* createAppAction(const KService::Ptr& service, bool singleOffer, QActionGroup *actionGroup);
 public:
   /** Event filter */
   bool eventFilter( QObject *obj, QEvent *ev );
@@ -324,6 +328,7 @@ public:
 
   /** Print message. */
   void printMessage( const Akonadi::Item &msg );
+  void printPreviousMessage( const Akonadi::Item &message );
 
   void resetStateForNewMessage();
 
@@ -464,6 +469,10 @@ private slots:
   void slotClear();
 
   void slotMessageRendered();
+  
+  void slotOpenWithAction(QAction *act);
+  void slotOpenWithDialog();
+  
 
   void saveSplitterSizes() const;
 
@@ -475,11 +484,14 @@ public slots:
   void slotUrlOn(const QString & link, const QString & title, const QString & textContent);
 
   /** The user presses the right mouse button on an URL. */
-  void slotUrlPopup(const QUrl &, const QPoint& mousePos);
+  void slotUrlPopup(const QUrl &, const QUrl &imageUrl, const QPoint& mousePos);
 
   /** The user selected "Find" from the menu. */
   void slotFind();
 
+  void slotTranslate();
+
+
   /** The user toggled the "Fixed Font" flag from the view menu. */
   void slotToggleFixedFont();
   void slotToggleMimePartTree();
@@ -515,6 +527,8 @@ public slots:
       In the very end it deletes the KMReaderWin window that was created
       for the purpose of rendering. */
   void slotPrintMsg();
+  void slotPrintPreview();
+
 
   void slotSetEncoding();
   void injectAttachments();
@@ -565,10 +579,12 @@ public slots:
   void slotZoomIn();
   void slotZoomOut();
   void slotZoomReset();
+  void slotSpeakText();
+  void slotCopyImageLocation();
 signals:
   void showStatusBarMessage( const QString &message );
   void replaceMsgByUnencryptedVersion();
-  void popupMenu(const Akonadi::Item &msg, const KUrl &url, const QPoint& mousePos);
+  void popupMenu(const Akonadi::Item &msg, const KUrl &url, const KUrl &imageUrl, const QPoint& mousePos);
   void urlClicked( const Akonadi::Item &msg, const KUrl &url );
   void requestConfigSync();
   void showReader( KMime::Content* aMsgPart, bool aHTML, const QString & encoding );
@@ -595,6 +611,7 @@ public:
   MimeTreeModel *mMimePartModel;
   MailWebView *mViewer;
   FindBarMailWebView *mFindBar;
+  TranslatorWidget *mTranslatorWidget;
 
   const AttachmentStrategy * mAttachmentStrategy;
   const HeaderStrategy * mHeaderStrategy;
@@ -625,8 +642,12 @@ public:
   KToggleAction *mToggleFixFontAction, *mToggleDisplayModeAction;
   KAction *mZoomTextOnlyAction, *mZoomInAction, *mZoomOutAction, *mZoomResetAction;
   KToggleAction *mToggleMimePartTreeAction;
+  KAction *mSpeakTextAction;
+  KAction *mCopyImageLocation;
+  KAction *mTranslateAction;
   KUrl mHoveredUrl;
   KUrl mClickedUrl;
+  KUrl mImageUrl;
   QPoint mLastClickPosition;
   bool mCanStartDrag;
   HtmlWriter * mHtmlWriter;
@@ -663,4 +684,6 @@ public:
 
 }
 
+Q_DECLARE_METATYPE(KService::Ptr)
+  
 #endif
