@@ -43,10 +43,6 @@
 
 #include <akonadi/agentactionmanager.h>
 #include <akonadi/calendar/standardcalendaractionmanager.h>
-#include <Akonadi/Calendar/IncidenceChanger>
-#include <Akonadi/Calendar/ITIPHandler>
-#include <akonadi/calendar/freebusymanager.h>
-#include <akonadi/calendar/calendarsettings.h>
 #include <akonadi/collectionmodel.h>
 #include <akonadi/collectionpropertiesdialog.h>
 #include <akonadi/entitytreemodel.h>
@@ -54,33 +50,84 @@
 #include <akonadi/itemfetchscope.h>
 #include <akonadi/standardactionmanager.h>
 #include <calendarsupport/archivedialog.h>
+#include <calendarsupport/calendar.h>
 #include <calendarsupport/categoryconfig.h>
+#include <calendarsupport/calendarmodel.h>
 #include <calendarsupport/collectiongeneralpage.h>
 #include <calendarsupport/collectionselection.h>
+#include <calendarsupport/freebusymanager.h>
 #include <calendarsupport/identitymanager.h>
 #include <calendarsupport/kcalprefs.h>
 #include <calendarsupport/utils.h>
-#include <calendarviews/eventview.h>
-#include <calendarviews/agenda/agendaview.h>
-#include <calendarviews/month/monthview.h>
+#include <calendarviews/eventviews/eventview.h>
+#include <calendarviews/eventviews/agenda/agendaview.h>
+#include <calendarviews/eventviews/month/monthview.h>
 #include <kaction.h>
 #include <kactioncollection.h>
 #include <kcalcore/event.h>
 #include <kcalcore/todo.h>
 #include <kcolorcombo.h>
+#ifndef _WIN32_WCE
 #include <kcolordialog.h>
+#endif
 #include <kmessagebox.h>
 #include <ksystemtimezone.h>
 #include <incidenceeditor-ng/categoryeditdialog.h>
 #include <incidenceeditor-ng/editorconfig.h>
+#include <incidenceeditor-ng/groupwareintegration.h>
 #include <incidenceeditor-ng/incidencedefaults.h>
 #include <libkdepimdbusinterfaces/reminderclient.h>
 
 #include <QtCore/QTimer>
 #include <QtDBus/QDBusConnection>
-#include <QDeclarativeEngine>
-#include <QDeclarativeContext>
-#include <QGraphicsItem>
+#include <QtDeclarative/QDeclarativeEngine>
+#include <QtDeclarative/QDeclarativeContext>
+#include <QtGui/QGraphicsItem>
+
+#ifdef Q_OS_WINCE
+class WinCEColorDialog : public KDialog
+{
+  public:
+    WinCEColorDialog( QWidget *parent = 0 )
+      : KDialog( parent )
+    {
+      QHBoxLayout *layout = new QHBoxLayout( mainWidget() );
+
+      QLabel *label = new QLabel( i18n( "Color:" ) );
+      mComboBox = new KPIM::KColorCombo;
+
+      layout->addWidget( label );
+      layout->addWidget( mComboBox );
+      layout->setStretch( 1, 1 );
+    }
+
+    void setColor( const QColor &color )
+    {
+      mComboBox->setColor( color );
+    }
+
+    QColor color() const
+    {
+      return mComboBox->color();
+    }
+
+    static int getColor( QColor &color )
+    {
+      WinCEColorDialog dialog;
+      dialog.setColor( color );
+
+      const int status = dialog.exec();
+
+      if ( status == KDialog::Accepted )
+        color = dialog.color();
+
+      return status;
+    }
+
+  private:
+    KPIM::KColorCombo *mComboBox;
+};
+#endif
 
 Q_DECLARE_METATYPE(KCalCore::iTIPMethod)
 
@@ -99,14 +146,14 @@ QML_DECLARE_TYPE( EventViews::TimelineViewItem )
 EventViews::PrefsPtr MainView::m_calendarPrefs;
 
 MainView::MainView( QWidget* parent )
-  : KDeclarativeMainView( QLatin1String("korganizer-mobile"), new EventListProxy, parent ),
+  : KDeclarativeMainView( "korganizer-mobile", new EventListProxy, parent ),
+    m_calendar( 0 ),
     m_identityManager( 0 ),
     m_changer( 0 ),
     mActionManager( 0 )
 {
   m_calendarPrefs = EventViews::PrefsPtr( new  EventViews::Prefs );
   m_calendarPrefs->readConfig();
-  mITIPHandler = new Akonadi::ITIPHandler( this );
 
   Akonadi::CollectionPropertiesDialog::registerPage( new CalendarSupport::CollectionGeneralPageFactory );
 }
@@ -141,14 +188,16 @@ void MainView::doDelayedInit()
   qmlRegisterType<ClockHelper>( "ClockHelper", 4, 5, "ClockHelper" );
   qmlRegisterUncreatableType<EventsGuiStateManager>( "org.kde.akonadi.events", 4, 5, "EventsGuiStateManager", QLatin1String( "This type is only exported for its enums" ) );
 
-  m_calendar = Akonadi::ETMCalendar::Ptr( new Akonadi::ETMCalendar() );
-  m_calendar->setWeakPointer( m_calendar );
-  engine()->rootContext()->setContextProperty( QLatin1String("calendarModel"), QVariant::fromValue( static_cast<QObject*>( m_calendar.data() ) ) );
-  Akonadi::FreeBusyManager::self()->setCalendar( m_calendar );
+  m_calendar = new CalendarSupport::Calendar( entityTreeModel(), itemModel(), KSystemTimeZones::local() );
+  engine()->rootContext()->setContextProperty( "calendarModel", QVariant::fromValue( static_cast<QObject*>( m_calendar ) ) );
+  CalendarSupport::FreeBusyManager::self()->setCalendar( m_calendar );
 
-  // TODO: set a groupware delegate to handle counter proposals
+  if ( !IncidenceEditorNG::GroupwareIntegration::isActive() ) {
+    IncidenceEditorNG::GroupwareIntegration::setGlobalUiDelegate( new GroupwareUiDelegate );
+    IncidenceEditorNG::GroupwareIntegration::activate( m_calendar );
+  }
 
-  m_changer = new Akonadi::IncidenceChanger( this );
+  m_changer = new CalendarSupport::IncidenceChanger( m_calendar, this );
 
   m_identityManager = new CalendarSupport::IdentityManager;
 
@@ -158,7 +207,7 @@ void MainView::doDelayedInit()
   collectionselection = new CalendarSupport::CollectionSelection( regularSelectionModel(), this );
   EventViews::EventView::setGlobalCollectionSelection( collectionselection );
 
-  QDBusConnection::sessionBus().registerService( QLatin1String("org.kde.korganizer") ); //register also as the real korganizer, so kmail can communicate with it
+  QDBusConnection::sessionBus().registerService( "org.kde.korganizer" ); //register also as the real korganizer, so kmail can communicate with it
 
   KAction *action = new KAction( i18n( "Import Events" ), this );
   connect( action, SIGNAL(triggered(bool)), SLOT(importItems()) );
@@ -230,7 +279,7 @@ void MainView::doDelayedInit()
   //register DBUS interface
   m_calendarIface = new CalendarInterface( this );
   new CalendarAdaptor( m_calendarIface );
-  QDBusConnection::sessionBus().registerObject( QLatin1String("/Calendar"), m_calendarIface );
+  QDBusConnection::sessionBus().registerObject( "/Calendar", m_calendarIface );
 
   KPIM::ReminderClient::startDaemon();
 }
@@ -272,7 +321,7 @@ void MainView::finishEdit( QObject *editor )
 
 void MainView::showRegularCalendar()
 {
-  //m_calendar->setUnfilteredModel( itemModel() );
+  m_calendar->setUnfilteredModel( itemModel() );
 }
 
 void MainView::setCurrentEventItemId( qint64 id )
@@ -315,7 +364,7 @@ void MainView::newEventWithDate( const QDate &date )
   //       This method should somehow depend on the calendar selected to which
   //       the incidence is added.
   if ( KCalPrefs::instance()->useGroupwareCommunication() )
-    defaults.setGroupWareDomain( KUrl( Akonadi::CalendarSettings::self()->freeBusyRetrieveUrl() ).host() );
+    defaults.setGroupWareDomain( KUrl( KCalPrefs::instance()->freeBusyRetrieveUrl() ).host() );
 
   defaults.setDefaults( event );
 
@@ -472,7 +521,7 @@ void MainView::setupStandardActionManager( QItemSelectionModel *collectionSelect
   mActionManager->action( StandardActionManager::MoveCollectionToDialog )->setText( i18n( "Move Calendar To" ) );
   mActionManager->action( StandardActionManager::CopyCollectionToDialog )->setText( i18n( "Copy Calendar To" ) );
 
-  actionCollection()->action( QLatin1String("synchronize_all_items") )->setText( i18n( "Synchronize All Accounts" ) );
+  actionCollection()->action( "synchronize_all_items" )->setText( i18n( "Synchronize All Accounts" ) );
 
   const QStringList pages = QStringList() << QLatin1String( "CalendarSupport::CollectionGeneralPage" )
                                           << QLatin1String( "Akonadi::CachePolicyPage" );
@@ -490,23 +539,23 @@ void MainView::updateActionTexts()
   const Akonadi::Item item = items.first();
   const QString mimeType = item.mimeType();
   if ( mimeType == KCalCore::Event::eventMimeType() ) {
-    actionCollection()->action( QLatin1String("akonadi_item_copy") )->setText( ki18np( "Copy Event", "Copy %1 Events" ).subs( itemCount ).toString() );
-    actionCollection()->action( QLatin1String("akonadi_item_copy_to_dialog") )->setText( i18n( "Copy Event To" ) );
-    actionCollection()->action( QLatin1String("akonadi_item_delete") )->setText( ki18np( "Delete Event", "Delete %1 Events" ).subs( itemCount ).toString() );
-    actionCollection()->action( QLatin1String("akonadi_item_move_to_dialog") )->setText( i18n( "Move Event To" ) );
-    actionCollection()->action( QLatin1String("akonadi_incidence_edit") )->setText( i18n( "Edit Event" ) );
+    actionCollection()->action( "akonadi_item_copy" )->setText( ki18np( "Copy Event", "Copy %1 Events" ).subs( itemCount ).toString() );
+    actionCollection()->action( "akonadi_item_copy_to_dialog" )->setText( i18n( "Copy Event To" ) );
+    actionCollection()->action( "akonadi_item_delete" )->setText( ki18np( "Delete Event", "Delete %1 Events" ).subs( itemCount ).toString() );
+    actionCollection()->action( "akonadi_item_move_to_dialog" )->setText( i18n( "Move Event To" ) );
+    actionCollection()->action( "akonadi_incidence_edit" )->setText( i18n( "Edit Event" ) );
   } else if ( mimeType == KCalCore::Todo::todoMimeType() ) {
-    actionCollection()->action( QLatin1String("akonadi_item_copy") )->setText( ki18np( "Copy Task", "Copy %1 Tasks" ).subs( itemCount ).toString() );
-    actionCollection()->action(QLatin1String( "akonadi_item_copy_to_dialog") )->setText( i18n( "Copy Task To" ) );
-    actionCollection()->action( QLatin1String("akonadi_item_delete") )->setText( ki18np( "Delete Task", "Delete %1 Tasks" ).subs( itemCount ).toString() );
-    actionCollection()->action( QLatin1String("akonadi_item_move_to_dialog") )->setText( i18n( "Move Task To" ) );
-    actionCollection()->action( QLatin1String("akonadi_incidence_edit") )->setText( i18n( "Edit Task" ) );
+    actionCollection()->action( "akonadi_item_copy" )->setText( ki18np( "Copy Task", "Copy %1 Tasks" ).subs( itemCount ).toString() );
+    actionCollection()->action( "akonadi_item_copy_to_dialog" )->setText( i18n( "Copy Task To" ) );
+    actionCollection()->action( "akonadi_item_delete" )->setText( ki18np( "Delete Task", "Delete %1 Tasks" ).subs( itemCount ).toString() );
+    actionCollection()->action( "akonadi_item_move_to_dialog" )->setText( i18n( "Move Task To" ) );
+    actionCollection()->action( "akonadi_incidence_edit" )->setText( i18n( "Edit Task" ) );
   } else if ( mimeType == KCalCore::Journal::journalMimeType() ) {
-    actionCollection()->action( QLatin1String("akonadi_item_copy") )->setText( ki18np( "Copy Journal", "Copy %1 Journals" ).subs( itemCount ).toString() );
-    actionCollection()->action( QLatin1String("akonadi_item_copy_to_dialog") )->setText( i18n( "Copy Journal To" ) );
-    actionCollection()->action( QLatin1String("akonadi_item_delete") )->setText( ki18np( "Delete Journal", "Delete %1 Journals" ).subs( itemCount ).toString() );
-    actionCollection()->action( QLatin1String("akonadi_item_move_to_dialog" ))->setText( i18n( "Move Journal To" ) );
-    actionCollection()->action( QLatin1String("akonadi_incidence_edit") )->setText( i18n( "Edit Journal" ) );
+    actionCollection()->action( "akonadi_item_copy" )->setText( ki18np( "Copy Journal", "Copy %1 Journals" ).subs( itemCount ).toString() );
+    actionCollection()->action( "akonadi_item_copy_to_dialog" )->setText( i18n( "Copy Journal To" ) );
+    actionCollection()->action( "akonadi_item_delete" )->setText( ki18np( "Delete Journal", "Delete %1 Journals" ).subs( itemCount ).toString() );
+    actionCollection()->action( "akonadi_item_move_to_dialog" )->setText( i18n( "Move Journal To" ) );
+    actionCollection()->action( "akonadi_incidence_edit" )->setText( i18n( "Edit Journal" ) );
   }
 }
 
@@ -562,12 +611,12 @@ bool MainView::useFilterLineEditInCurrentState() const
 
 void MainView::uploadFreeBusy()
 {
-  Akonadi::FreeBusyManager::self()->publishFreeBusy( this );
+  CalendarSupport::FreeBusyManager::self()->publishFreeBusy( this );
 }
 
 void MainView::mailFreeBusy()
 {
-  Akonadi::FreeBusyManager::self()->mailFreeBusy( 30, this );
+  CalendarSupport::FreeBusyManager::self()->mailFreeBusy( 30, this );
 }
 
 void MainView::sendAsICalendar()
@@ -596,9 +645,7 @@ void MainView::fetchForSendICalDone( KJob *job )
 
   const Akonadi::Item item = static_cast<Akonadi::ItemFetchJob*>( job )->items().first();
 
-  KCalCore::Incidence::Ptr incidence = CalendarSupport::incidence( item );
-  if ( incidence )
-    mITIPHandler->sendAsICalendar( incidence, this );
+  CalendarSupport::sendAsICalendar( item, m_identityManager, this );
 }
 
 void MainView::publishItemInformation()
@@ -627,10 +674,7 @@ void MainView::fetchForPublishItemDone( KJob *job )
 
   const Akonadi::Item item = static_cast<Akonadi::ItemFetchJob*>( job )->items().first();
 
-
-  KCalCore::Incidence::Ptr incidence = CalendarSupport::incidence( item );
-  if ( incidence )
-    mITIPHandler->publishInformation( incidence, this );
+  CalendarSupport::publishItemInformation( item, m_calendar, this );
 }
 
 void MainView::sendInvitation()
@@ -686,9 +730,7 @@ void MainView::fetchForiTIPMethodDone( KJob *job )
   const Akonadi::Item item = static_cast<Akonadi::ItemFetchJob*>( job )->items().first();
 
   const KCalCore::iTIPMethod method = job->property( "iTIPmethod" ).value<KCalCore::iTIPMethod>();
-  const KCalCore::Incidence::Ptr incidence = CalendarSupport::incidence( item );
-  if ( incidence )
-    mITIPHandler->sendiTIPMessage( method, incidence, this );
+  CalendarSupport::scheduleiTIPMethods( method, item, m_calendar, this );
 }
 
 void MainView::saveAllAttachments()
@@ -716,7 +758,37 @@ void MainView::fetchForSaveAllAttachmentsDone( KJob *job )
   }
 
   const Akonadi::Item item = static_cast<Akonadi::ItemFetchJob*>( job )->items().first();
+#ifndef Q_OS_WINCE
   CalendarSupport::saveAttachments( item, this );
+#else
+  // CalendarSupport is not completely ported for Windows CE so we use the
+  // attachment handling code from KDeclarativeMainView
+  KCalCore::Incidence::Ptr incidence = CalendarSupport::incidence( item );
+
+  if ( !incidence ) {
+    KMessageBox::sorry(
+      this,
+      i18n( "No item selected." ),
+      "SaveAttachments" );
+    return;
+  }
+
+  KCalCore::Attachment::List attachments = incidence->attachments();
+
+  if ( attachments.empty() )
+    return;
+
+  Q_FOREACH( KCalCore::Attachment::Ptr attachment, attachments ) {
+    QString fileName = attachment->label();
+    QString sourceUrl;
+    if ( attachment->isUri() ) {
+      sourceUrl = attachment->uri();
+    } else {
+      sourceUrl = incidence->writeAttachmentToTempFile( attachment );
+    }
+      saveAttachment( sourceUrl, fileName );
+  }
+#endif //Q_OS_WINCE
 }
 
 void MainView::archiveOldEntries()
@@ -742,8 +814,11 @@ void MainView::changeCalendarColor()
   QColor calendarColor = agendaItem->preferences()->resourceColor( id );
   QColor myColor;
 
+#ifdef Q_OS_WINCE
+  const int result = WinCEColorDialog::getColor( myColor );
+#else
   const int result = KColorDialog::getColor( myColor, calendarColor );
-
+#endif
   if ( result == KDialog::Accepted && myColor != calendarColor ) {
     agendaItem->preferences()->setResourceColor( id, myColor );
     agendaItem->updateConfig();
@@ -760,3 +835,4 @@ void MainView::changeCalendarColor()
 
 
 
+#include "mainview.moc"
