@@ -76,8 +76,6 @@ using namespace KCalCore;
 #include <KToolInvocation>
 #include <KIO/NetAccess>
 
-using namespace MailTransport;
-
 namespace {
 
 static bool hasMyWritableEventsFolders( const QString &family )
@@ -280,16 +278,16 @@ static QString directoryForStatus( Attendee::PartStat status )
   QString dir;
   switch ( status ) {
   case Attendee::Accepted:
-    dir = "accepted";
+    dir = QLatin1String( "accepted" );
     break;
   case Attendee::Tentative:
-    dir = "tentative";
+    dir = QLatin1String( "tentative" );
     break;
   case Attendee::Declined:
-    dir = "cancel";
+    dir = QLatin1String( "cancel" );
     break;
   case Attendee::Delegated:
-    dir = "delegated";
+    dir = QLatin1String( "delegated" );
     break;
   default:
     break;
@@ -344,7 +342,7 @@ class UrlHandler : public Interface::BodyPartURLHandler
       bool rsvp = true; // better send superfluously than not at all
       Attendee::List attendees = incidence->attendees();
       Attendee::List::ConstIterator it;
-      Attendee::List::ConstIterator end( attendees.constEnd() );      
+      Attendee::List::ConstIterator end( attendees.constEnd() );
       for ( it = attendees.constBegin(); it != end; ++it ) {
         if ( it == attendees.constBegin() ) {
           rsvp = (*it)->RSVP(); // use what the first one has
@@ -364,7 +362,7 @@ class UrlHandler : public Interface::BodyPartURLHandler
       Attendee::List attendees = incidence->attendees();
       Attendee::List::ConstIterator it;
       Attendee::List::ConstIterator end = attendees.constEnd();
-      
+
       for ( it = attendees.constBegin(); it != end; ++it ) {
         if ( it == attendees.constBegin() ) {
           role = (*it)->role(); // use what the first one has
@@ -389,7 +387,7 @@ class UrlHandler : public Interface::BodyPartURLHandler
       if ( attachments.count() > 0 ) {
         Attachment::List::ConstIterator it;
         Attachment::List::ConstIterator end = attachments.constEnd();
-        
+
         for ( it = attachments.constBegin(); it != end; ++it ) {
           if ( (*it)->label() == name ) {
             attachment = *it;
@@ -600,22 +598,23 @@ class UrlHandler : public Interface::BodyPartURLHandler
         msg->setHeader( x_header );
       }
 
+#if 0 //TODO: Review // Shouldn't be necessary anymore
       const bool identityHasTransport = !identity.transport().isEmpty();
-      QString transportName;
       if ( !nullIdentity && identityHasTransport ) {
-          transportName = identity.transport();
+        msg->setHeaderField( "X-KMail-Transport", identity.transport() );
       } else if ( !nullIdentity && identity.isDefault() ) {
-          transportName = TransportManager::self()->defaultTransportName();
+        msg->setHeaderField( "X-KMail-Transport",
+                             TransportManager::self()->defaultTransportName() );
       } else {
-          transportName = TransportManager::self()->defaultTransportName();
+        const QString transport = askForTransport( nullIdentity );
+        if ( transport.isEmpty() ) {
+          return false; // user canceled transport selection dialog
+        }
+        msg->setHeaderField( "X-KMail-Transport", transport );
       }
-
-      if(transportName.isEmpty()) {
-        if ( !TransportManager::self()->showTransportCreationDialog( 0, TransportManager::IfNoTransportExists ) )
-          return false;
-        transportName = TransportManager::self()->defaultTransportName();
-      }
-      msg->setHeader( new KMime::Headers::Generic( "X-KMail-Transport", msg.get(), transportName, "utf-8" ) );
+#else
+      kDebug() << "AKONADI PORT: Disabled code in " << Q_FUNC_INFO;
+#endif
 
       // Outlook will only understand the reply if the From: header is the
       // same as the To: header of the invitation message.
@@ -659,10 +658,11 @@ class UrlHandler : public Interface::BodyPartURLHandler
       }
 #else
       msg->assemble();
-      MailTransport::Transport *transport = MailTransport::TransportManager::self()->transportByName( transportName );
+      MailTransport::Transport *transport = MailTransport::TransportManager::self()->transportByName( MailTransport::TransportManager::self()->defaultTransportName() );
+
 
       MailTransport::MessageQueueJob *job = new MailTransport::MessageQueueJob;
-      
+
       job->addressAttribute().setTo( QStringList() << KPIMUtils::extractEmailAddress(
                                        KPIMUtils::normalizeAddressesAndEncodeIdn( to ) ) );
       job->transportAttribute().setTransportId(
@@ -679,7 +679,7 @@ class UrlHandler : public Interface::BodyPartURLHandler
       }
 
       job->setMessage( msg );
-      
+
       if( ! job->exec() ) {
         kWarning() << "Error queuing message in outbox:" << job->errorText();
         return false;
@@ -906,7 +906,12 @@ class UrlHandler : public Interface::BodyPartURLHandler
         if ( !ok ) {
           return true;
         }
-        if ( !comment.isEmpty() ) {
+        if ( comment.isEmpty() ) {
+          KMessageBox::error(
+            0,
+            i18n( "You forgot to add proposal. Please add it. Thanks" ) );
+          return true;
+        } else {
           if ( GlobalSettings::self()->outlookCompatibleInvitationReplyComments() ) {
             incidence->setDescription( comment );
           } else {
@@ -1147,7 +1152,14 @@ class UrlHandler : public Interface::BodyPartURLHandler
         if ( !ok ) {
           return true;
         }
-        if ( !comment.isEmpty() ) {
+        if ( comment.isEmpty() ) {
+          KMessageBox::error(
+            0,
+            i18n( "You forgot to add proposal. Please add it. Thanks" ) );
+          return true;
+
+        }
+        else {
           if ( GlobalSettings::self()->outlookCompatibleInvitationReplyComments() ) {
             incidence->setDescription( comment );
           } else {
