@@ -1,41 +1,37 @@
-/*   -*- mode: C++; c-file-style: "gnu" -*-
-*   kmail: KDE mail client
-*   Copyright (C) 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
-*   Copyright (C) 2011 Laurent Montel <montel@kde.org>
-*
-*   This program is free software; you can redistribute it and/or modify
-*   it under the terms of the GNU General Public License as published by
-*   the Free Software Foundation; either version 2 of the License, or
-*   (at your option) any later version.
-*
-*   This program is distributed in the hope that it will be useful,
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*   GNU General Public License for more details.
-*
-*   You should have received a copy of the GNU General Public License along
-*   with this program; if not, write to the Free Software Foundation, Inc.,
-*   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-*
-*/
+/*
+ * Copyright (C) 2006 Dmitry Morozhnikov <dmiceman@mail.ru>
+ * Copyright (C) 2011,2012 Laurent Montel <montel@kde.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ */
 
 #include "customtemplates.h"
+#include "customtemplates_kfg.h"
+#include "globalsettings_base.h"
+#include "ui_customtemplates_base.h"
+
+#include <KIconLoader>
+#include <KLocale>
+#include <KMessageBox>
 
 #include <QWhatsThis>
 
-#include <klocale.h>
-#include <kglobal.h>
-#include <kiconloader.h>
-#include <kpushbutton.h>
-#include <klineedit.h>
-#include <kmessagebox.h>
-#include <kkeysequencewidget.h>
+using namespace TemplateParser;
 
-#include "ui_customtemplates_base.h"
-#include "customtemplates_kfg.h"
-#include "globalsettings_base.h"
-
-CustomTemplates::CustomTemplates( const QList<KActionCollection*>& actionCollection, QWidget *parent )
+CustomTemplates::CustomTemplates( const QList<KActionCollection*> &actionCollection,
+                                  QWidget *parent )
   : QWidget( parent ),
     mBlockChangeSignal( false )
 {
@@ -45,16 +41,16 @@ CustomTemplates::CustomTemplates( const QList<KActionCollection*>& actionCollect
   mUi->mAdd->setIcon( KIcon( "list-add" ) );
   mUi->mAdd->setEnabled( false );
   mUi->mRemove->setIcon( KIcon( "list-remove" ) );
+  mUi->mDuplicate->setIcon( KIcon( "edit-copy" ) );
 
   mUi->mList->setColumnWidth( 0, 100 );
   mUi->mList->header()->setStretchLastSection( true );
-  mUi->mList->setItemDelegate(new CustomTemplateItemDelegate(this));
-
+  mUi->mList->setItemDelegate( new CustomTemplateItemDelegate( this ) );
   mUi->mEditFrame->setEnabled( false );
 
   mUi->mName->setTrapReturnKey( true );
   connect( mUi->mEdit, SIGNAL(textChanged()),
-          this, SLOT(slotTextChanged()) );
+           this, SLOT(slotTextChanged()) );
   connect( mUi->mToEdit, SIGNAL(textChanged()),
            this, SLOT(slotTextChanged()) );
   connect( mUi->mCCEdit, SIGNAL(textChanged()),
@@ -67,18 +63,20 @@ CustomTemplates::CustomTemplates( const QList<KActionCollection*>& actionCollect
            this, SLOT(slotAddClicked()) );
 
   connect( mUi->mInsertCommand, SIGNAL(insertCommand(QString,int)),
-          this, SLOT(slotInsertCommand(QString,int)) );
+           this, SLOT(slotInsertCommand(QString,int)) );
 
   connect( mUi->mAdd, SIGNAL(clicked()),
-          this, SLOT(slotAddClicked()) );
+           this, SLOT(slotAddClicked()) );
   connect( mUi->mRemove, SIGNAL(clicked()),
-          this, SLOT(slotRemoveClicked()) );
-  connect(mUi->mList, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),
-          this, SLOT(slotListSelectionChanged()) );
-  connect(mUi->mList, SIGNAL(itemChanged(QTreeWidgetItem*,int)),
-          this, SLOT(slotItemChanged(QTreeWidgetItem*,int)) );
+           this, SLOT(slotRemoveClicked()) );
+  connect( mUi->mDuplicate, SIGNAL(clicked()),
+           this, SLOT(slotDuplicateClicked()) );
+  connect( mUi->mList, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)),
+           this, SLOT(slotListSelectionChanged()) );
+  connect( mUi->mList, SIGNAL(itemChanged(QTreeWidgetItem*,int)),
+           this, SLOT(slotItemChanged(QTreeWidgetItem*,int)) );
   connect( mUi->mType, SIGNAL(activated(int)),
-          this, SLOT(slotTypeActivated(int)) );
+           this, SLOT(slotTypeActivated(int)) );
 
   connect( mUi->mKeySequenceWidget, SIGNAL(keySequenceChanged(QKeySequence)),
           this, SLOT(slotShortcutChanged(QKeySequence)) );
@@ -99,43 +97,26 @@ CustomTemplates::CustomTemplates( const QList<KActionCollection*>& actionCollect
   connect( mUi->mHelp, SIGNAL(linkActivated(QString)),
           SLOT(slotHelpLinkClicked(QString)) );
 
-  const QString toToolTip = i18n( "Additional recipients of the message" );
-  const QString ccToolTip = i18n( "Additional recipients who get a copy of the message" );
-  const QString toWhatsThis = i18n( "When using this template, the default recipients are those you enter here. This is a comma-separated list of mail addresses." );
-  const QString ccWhatsThis = i18n( "When using this template, the recipients you enter here will by default get a copy of this message. This is a comma-separated list of mail addresses." );
-
-  KLineEdit *ccLineEdit = mUi->mCCEdit->lineEdit();
-  KLineEdit *toLineEdit = mUi->mToEdit->lineEdit();
-
-  mUi->mCCLabel->setToolTip( ccToolTip );
-  ccLineEdit->setToolTip( ccToolTip );
-  mUi->mToLabel->setToolTip( toToolTip );
-  toLineEdit->setToolTip( toToolTip );
-  mUi->mCCLabel->setWhatsThis( ccWhatsThis );
-  ccLineEdit->setWhatsThis( ccWhatsThis );
-  mUi->mToLabel->setWhatsThis( toWhatsThis );
-  toLineEdit->setWhatsThis( toWhatsThis );
-
   slotNameChanged( mUi->mName->text() );
 }
 
-void CustomTemplates::slotHelpLinkClicked( const QString& )
+void CustomTemplates::slotHelpLinkClicked( const QString & )
 {
   const QString help =
-      i18n( "<qt>"
-      "<p>Here you can add, edit, and delete custom message "
-      "templates to use when you compose a reply or forwarding message. "
-      "Create the custom template by typing the name into the input box "
-      "and press the '+' button. Also, you can bind a keyboard "
-      "combination to the template for faster operations.</p>"
-      "<p>Message templates support substitution commands, "
-      "by simply typing them or selecting them from the "
-      "<i>Insert command</i> menu.</p>"
-      "<p>There are four types of custom templates: used to "
-      "<i>Reply</i>, <i>Reply to All</i>, <i>Forward</i>, and "
-      "<i>Universal</i> which can be used for all kinds of operations. "
-      "You cannot bind a keyboard shortcut to <i>Universal</i> templates.</p>"
-      "</qt>" );
+    i18n( "<qt>"
+          "<p>Here you can add, edit, and delete custom message "
+          "templates to use when you compose a reply or forwarding message. "
+          "Create the custom template by typing the name into the input box "
+          "and press the '+' button. Also, you can bind a keyboard "
+          "combination to the template for faster operations.</p>"
+          "<p>Message templates support substitution commands, "
+          "by simply typing them or selecting them from the "
+          "<i>Insert command</i> menu.</p>"
+          "<p>There are four types of custom templates: used to "
+          "<i>Reply</i>, <i>Reply to All</i>, <i>Forward</i>, and "
+          "<i>Universal</i> which can be used for all kinds of operations. "
+          "You cannot bind a keyboard shortcut to <i>Universal</i> templates.</p>"
+          "</qt>" );
 
   QWhatsThis::showText( QCursor::pos(), help );
 }
@@ -146,7 +127,7 @@ CustomTemplates::~CustomTemplates()
   mUi = 0;
 }
 
-void CustomTemplates::slotNameChanged( const QString& text )
+void CustomTemplates::slotNameChanged( const QString &text )
 {
   mUi->mAdd->setEnabled( !text.isEmpty() );
 }
@@ -156,17 +137,23 @@ QString CustomTemplates::indexToType( int index )
   QString typeStr;
   switch ( index ) {
   case TUniversal:
-    typeStr = i18nc( "Message->", "Universal" ); break;
+    typeStr = i18nc( "Message->", "Universal" );
+    break;
 /*  case TNewMessage:
-    typeStr = i18n( "New Message" ); break;*/
+    typeStr = i18n( "New Message" );
+    break; */
   case TReply:
-    typeStr = i18nc( "Message->", "Reply" ); break;
+    typeStr = i18nc( "Message->", "Reply" );
+    break;
   case TReplyAll:
-    typeStr = i18nc( "Message->", "Reply to All" ); break;
+    typeStr = i18nc( "Message->", "Reply to All" );
+    break;
   case TForward:
-    typeStr = i18nc( "Message->", "Forward" ); break;
+    typeStr = i18nc( "Message->", "Forward" );
+    break;
   default:
-    typeStr = i18nc( "Message->", "Unknown" ); break;
+    typeStr = i18nc( "Message->", "Unknown" );
+    break;
   }
   return typeStr;
 }
@@ -183,40 +170,48 @@ void CustomTemplates::slotTextChanged()
     }
   }
 
-  if ( !mBlockChangeSignal )
+  if ( !mBlockChangeSignal ) {
     emit changed();
+  }
+}
+
+void CustomTemplates::iconFromType( CustomTemplates::Type type, CustomTemplateItem *item )
+{
+  switch ( type ) {
+  case TReply:
+    item->setIcon( 0, mReplyPix );
+    break;
+  case TReplyAll:
+    item->setIcon( 0, mReplyAllPix );
+    break;
+  case TForward:
+    item->setIcon( 0, mForwardPix );
+    break;
+  default:
+    item->setIcon( 0, QPixmap() );
+    break;
+  };
+
 }
 
 void CustomTemplates::load()
 {
-  const QStringList list = TemplateParser::GlobalSettings::self()->customTemplates();
+  const QStringList list = GlobalSettings::self()->customTemplates();
   mUi->mList->clear();
   QStringList::const_iterator end( list.constEnd() );
   for ( QStringList::const_iterator it = list.constBegin(); it != end; ++it ) {
     CTemplates t(*it);
     QKeySequence shortcut( t.shortcut() );
     CustomTemplates::Type type = static_cast<Type>( t.type() );
-    CustomTemplateItem *item = new CustomTemplateItem( mUi->mList, *it, t.content(),shortcut, type, t.to(), t.cC() );
+    CustomTemplateItem *item = new CustomTemplateItem( mUi->mList, *it, t.content(),
+                                                       shortcut, type, t.to(), t.cC() );
     item->setText( 1, *it );
     item->setText( 0, indexToType( type ) );
-
-    switch ( type ) {
-    case TReply:
-      item->setIcon( 0, mReplyPix );
-      break;
-    case TReplyAll:
-      item->setIcon( 0, mReplyAllPix );
-      break;
-    case TForward:
-      item->setIcon( 0, mForwardPix );
-      break;
-    default:
-      item->setIcon( 0, QPixmap() );
-      break;
-    };
+    iconFromType( type, item );
   }
 
   mUi->mRemove->setEnabled( mUi->mList->topLevelItemCount() > 0 && mUi->mList->currentItem() );
+  mUi->mDuplicate->setEnabled( mUi->mList->topLevelItemCount() > 0 && mUi->mList->currentItem() );
 }
 
 void CustomTemplates::save()
@@ -224,7 +219,7 @@ void CustomTemplates::save()
   // Before saving the new templates, delete the old ones. That needs to be done before
   // saving, since otherwise a new template with the new name wouldn't get saved.
   KSharedConfig::Ptr config = KSharedConfig::openConfig( "customtemplatesrc", KConfig::NoGlobals );
-  foreach( const QString &item, mItemsToDelete ) {
+  foreach ( const QString &item, mItemsToDelete ) {
     CTemplates t( item );
     const QString configGroup = t.currentGroup();
     config->deleteGroup( configGroup );
@@ -252,8 +247,8 @@ void CustomTemplates::save()
     ++lit;
   }
 
-  TemplateParser::GlobalSettings::self()->setCustomTemplates( list );
-  TemplateParser::GlobalSettings::self()->writeConfig();
+  GlobalSettings::self()->setCustomTemplates( list );
+  GlobalSettings::self()->writeConfig();
 
   emit templatesUpdated();
 }
@@ -267,12 +262,12 @@ void CustomTemplates::slotInsertCommand( const QString &cmd, int adjustCursor )
   mUi->mEdit->setFocus();
 }
 
-bool CustomTemplates::nameAlreadyExists( const QString& str,QTreeWidgetItem *item )
+bool CustomTemplates::nameAlreadyExists( const QString &str, QTreeWidgetItem *item )
 {
   QTreeWidgetItemIterator lit( mUi->mList );
   while ( *lit ) {
     const QString name = ( *lit )->text( 1 );
-    if ( ( name == str ) && ( ( *lit ) != item )) {
+    if ( ( name == str ) && ( (*lit) != item ) ) {
       KMessageBox::error(
         this,
         i18n( "A template with same name already exists." ),
@@ -283,7 +278,6 @@ bool CustomTemplates::nameAlreadyExists( const QString& str,QTreeWidgetItem *ite
   }
   return false;
 }
-  
 
 void CustomTemplates::slotAddClicked()
 {
@@ -294,36 +288,104 @@ void CustomTemplates::slotAddClicked()
     }
 
     // KShortcut::null() doesn't seem to be present, although documented
-    // at http://developer.kde.org/documentation/library/cvs-api/kdelibs-apidocs/kdecore/html/classKShortcut.html
-    // see slotShortcutChanged(). oh, and you should look up documentation on the english breakfast network!
+    // see slotShortcutChanged(). oh, and you should look up documentation on the EBN!
     // FIXME There must be a better way of doing this...
     QKeySequence nullShortcut;
     CustomTemplateItem *item =
       new CustomTemplateItem( mUi->mList, str, "", nullShortcut, TUniversal,
-                           QString(), QString());
+                              QString(), QString() );
     item->setText( 0, indexToType( TUniversal ) );
     item->setText( 1, str );
     mUi->mList->setCurrentItem( item );
     mUi->mRemove->setEnabled( true );
+    mUi->mDuplicate->setEnabled( true );
     mUi->mName->clear();
     mUi->mKeySequenceWidget->setEnabled( false );
-    if ( !mBlockChangeSignal )
+    if ( !mBlockChangeSignal ) {
       emit changed();
+    }
   }
 }
 
+QString CustomTemplates::createUniqueName( const QString &name ) const
+{
+  QString uniqueName = name;
+
+  int counter = 0;
+  bool found = true;
+
+  while ( found ) {
+    found = false;
+
+    QTreeWidgetItemIterator lit( mUi->mList );
+    while ( *lit ) {
+      const QString itemName = ( *lit )->text( 1 );
+      if ( !itemName.compare( uniqueName ) ) {
+        found = true;
+        ++counter;
+        uniqueName = name;
+        uniqueName += QString( " (" ) + QString::number( counter ) + QString( ")" );
+        break;
+      }
+      lit++;
+    }
+  }
+
+  return uniqueName;
+}
+
+void CustomTemplates::slotDuplicateClicked()
+{
+  QTreeWidgetItem *currentItem = mUi->mList->currentItem();
+  if ( !currentItem ) {
+    return;
+  }
+  CustomTemplateItem * origItem = static_cast<CustomTemplateItem*>( currentItem );
+  const QString templateName = createUniqueName( origItem->text( 1 ) );
+  // KShortcut::null() doesn't seem to be present, although documented
+  // see slotShortcutChanged(). oh, and you should look up documentation on the EBN!
+  // FIXME There must be a better way of doing this...
+  QKeySequence nullShortcut;
+  CustomTemplates::Type type =  origItem->customType();
+  CustomTemplateItem *item =
+      new CustomTemplateItem( mUi->mList, templateName, origItem->content(), nullShortcut, type,
+                              origItem->to(), origItem->cc() );
+  item->setText( 0, indexToType( type ) );
+  item->setText( 1, templateName );
+  iconFromType( type, item );
+
+  mUi->mList->setCurrentItem( item );
+  mUi->mRemove->setEnabled( true );
+  mUi->mDuplicate->setEnabled( true );
+  mUi->mName->clear();
+  mUi->mKeySequenceWidget->setEnabled( type != TUniversal );
+
+  emit changed();
+}
+
 void CustomTemplates::slotRemoveClicked()
 {
-  QTreeWidgetItem * item = mUi->mList->currentItem();
-  if ( !item )
+  QTreeWidgetItem *item = mUi->mList->currentItem();
+  if ( !item ) {
     return;
+  }
 
   const QString templateName = item->text( 1 );
-  mItemsToDelete.append( templateName );
-  delete mUi->mList->takeTopLevelItem( mUi->mList->indexOfTopLevelItem( item ) );
-  mUi->mRemove->setEnabled( mUi->mList->topLevelItemCount() > 0 );
-  if ( !mBlockChangeSignal )
-    emit changed();
+
+  if ( KMessageBox::warningContinueCancel(
+         this,
+         i18nc( "@info", "Do you really want to remove template \"%1\"?", templateName ),
+         i18nc( "@title:window", "Remove Template?" ),
+         KStandardGuiItem::remove(),
+         KStandardGuiItem::cancel() ) == KMessageBox::Continue ) {
+    mItemsToDelete.append( templateName );
+    delete mUi->mList->takeTopLevelItem( mUi->mList->indexOfTopLevelItem( item ) );
+    mUi->mRemove->setEnabled( mUi->mList->topLevelItemCount() > 0 );
+    mUi->mDuplicate->setEnabled( mUi->mList->topLevelItemCount() > 0 );
+    if ( !mBlockChangeSignal ) {
+      emit changed();
+    }
+  }
 }
 
 void CustomTemplates::slotListSelectionChanged()
@@ -332,12 +394,15 @@ void CustomTemplates::slotListSelectionChanged()
   if ( item ) {
     mUi->mEditFrame->setEnabled( true );
     mUi->mRemove->setEnabled(true);
+    mUi->mDuplicate->setEnabled(true);
     CustomTemplateItem *vitem = static_cast<CustomTemplateItem*>( item );
     mBlockChangeSignal = true;
     mUi->mEdit->setText( vitem->content() );
     mUi->mKeySequenceWidget->setKeySequence( vitem->shortcut(),
                                              KKeySequenceWidget::NoValidate );
-    mUi->mType->setCurrentIndex( mUi->mType->findText( indexToType ( vitem->customType() ) ) );
+    CustomTemplates::Type type =  vitem->customType();
+
+    mUi->mType->setCurrentIndex( mUi->mType->findText( indexToType ( type ) ) );
     mUi->mToEdit->setText( vitem->to() );
     mUi->mCCEdit->setText( vitem->cc() );
     mBlockChangeSignal = false;
@@ -347,7 +412,7 @@ void CustomTemplates::slotListSelectionChanged()
     // a universal, as otherwise we won't know what sort of action to do when the
     // key sequence is activated!
     // This agrees with KMMainWidget::updateCustomTemplateMenus() -- marten
-    mUi->mKeySequenceWidget->setEnabled( vitem->customType() != TUniversal );
+    mUi->mKeySequenceWidget->setEnabled( type != TUniversal );
   } else {
     mUi->mEditFrame->setEnabled( false );
     mUi->mEdit->clear();
@@ -366,28 +431,16 @@ void CustomTemplates::slotTypeActivated( int index )
     CustomTemplateItem *vitem = static_cast<CustomTemplateItem*>( item );
     CustomTemplates::Type customtype = static_cast<Type>(index);
     vitem->setCustomType( customtype );
-    mUi->mList->currentItem()->setText( 0, indexToType( customtype ) );
+    vitem->setText( 0, indexToType( customtype ) );
 
-    switch ( customtype ) {
-    case TReply:
-      mUi->mList->currentItem()->setIcon( 0, mReplyPix );
-      break;
-    case TReplyAll:
-      mUi->mList->currentItem()->setIcon( 0, mReplyAllPix );
-      break;
-    case TForward:
-      mUi->mList->currentItem()->setIcon( 0, mForwardPix );
-      break;
-    default:
-      mUi->mList->currentItem()->setIcon( 0, QPixmap() );
-      break;
-    };
+    iconFromType( customtype, vitem );
 
     // see slotListSelectionChanged() above
     mUi->mKeySequenceWidget->setEnabled( customtype != TUniversal );
 
-    if ( !mBlockChangeSignal )
+    if ( !mBlockChangeSignal ) {
       emit changed();
+    }
   }
 }
 
@@ -400,11 +453,12 @@ void CustomTemplates::slotShortcutChanged( const QKeySequence &newSeq )
     mUi->mKeySequenceWidget->applyStealShortcut();
   }
 
-  if ( !mBlockChangeSignal )
+  if ( !mBlockChangeSignal ) {
     emit changed();
+  }
 }
 
-void CustomTemplates::slotItemChanged(QTreeWidgetItem* item ,int column)
+void CustomTemplates::slotItemChanged( QTreeWidgetItem *item, int column )
 {
   if ( item ) {
     CustomTemplateItem * vitem = static_cast<CustomTemplateItem*>( item );
@@ -419,16 +473,17 @@ void CustomTemplates::slotItemChanged(QTreeWidgetItem* item ,int column)
         if ( newName != oldName ) {
           mItemsToDelete.append( oldName );
           vitem->setOldName( newName );
-          if ( !mBlockChangeSignal )
+          if ( !mBlockChangeSignal ) {
             emit changed();
+          }
         }
       }
     }
   }
 }
 
-CustomTemplateItemDelegate::CustomTemplateItemDelegate(QObject *parent )
-  :QStyledItemDelegate( parent )
+CustomTemplateItemDelegate::CustomTemplateItemDelegate( QObject *parent )
+  : QStyledItemDelegate( parent )
 {
 }
 
@@ -436,40 +491,42 @@ CustomTemplateItemDelegate::~CustomTemplateItemDelegate()
 {
 }
 
-void CustomTemplateItemDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
-                                    const QModelIndex &index) const
+void CustomTemplateItemDelegate::setModelData( QWidget *editor, QAbstractItemModel *model,
+                                               const QModelIndex &index ) const
 {
-  QLineEdit *lineEdit = static_cast<QLineEdit*>(editor);
+  KLineEdit *lineEdit = static_cast<KLineEdit*>( editor );
   const QString text = lineEdit->text();
   if( !text.isEmpty() ) {
     model->setData( index, text, Qt::EditRole );
   }
 }
 
-QWidget *CustomTemplateItemDelegate::createEditor( QWidget * parent, const QStyleOptionViewItem & option, const QModelIndex & index ) const
+QWidget *CustomTemplateItemDelegate::createEditor( QWidget *parent,
+                                                   const QStyleOptionViewItem &option,
+                                                   const QModelIndex &index ) const
 {
-  if ( index.column() == 1 )
+  if ( index.column() == 1 ) {
     return QStyledItemDelegate::createEditor( parent, option, index );
+  }
   return 0;
 }
 
-  
 CustomTemplateItem::CustomTemplateItem( QTreeWidget *parent,
                                         const QString &name,
                                         const QString &content,
                                         const QKeySequence &shortcut,
                                         CustomTemplates::Type type,
-                                        const QString& to,
-                                        const QString& cc )
-  :QTreeWidgetItem( parent ),
-   mName( name ),
-   mContent( content ),
-   mShortcut(shortcut),
-   mType( type ),
-   mTo( to ),
-   mCC( cc )
+                                        const QString &to,
+                                        const QString &cc )
+  : QTreeWidgetItem( parent ),
+    mName( name ),
+    mContent( content ),
+    mShortcut(shortcut),
+    mType( type ),
+    mTo( to ),
+    mCC( cc )
 {
-  setFlags(flags() | Qt::ItemIsEditable);
+  setFlags( flags() | Qt::ItemIsEditable );
 }
 
 CustomTemplateItem::~CustomTemplateItem()
@@ -501,17 +558,17 @@ QString CustomTemplateItem::content() const
   return mContent;
 }
 
-void CustomTemplateItem::setContent(const QString& content )
+void CustomTemplateItem::setContent( const QString &content )
 {
   mContent = content;
 }
 
-void CustomTemplateItem::setTo(const QString& to)
+void CustomTemplateItem::setTo( const QString &to )
 {
   mTo = to;
 }
 
-void CustomTemplateItem::setCc(const QString& cc)
+void CustomTemplateItem::setCc( const QString &cc )
 {
   mCC = cc;
 }
@@ -521,7 +578,7 @@ QKeySequence CustomTemplateItem::shortcut() const
   return mShortcut;
 }
 
-void CustomTemplateItem::setShortcut(const QKeySequence& shortcut)
+void CustomTemplateItem::setShortcut( const QKeySequence &shortcut )
 {
   mShortcut = shortcut;
 }
@@ -531,7 +588,7 @@ QString CustomTemplateItem::oldName() const
   return mName;
 }
 
-void CustomTemplateItem::setOldName(const QString& name)
+void CustomTemplateItem::setOldName( const QString &name )
 {
   mName = name;
 }
